Class: Google::Cloud::Dialogflow::V2::AgentCoachingInstruction::DuplicateCheckResult::DuplicateSuggestion
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::AgentCoachingInstruction::DuplicateCheckResult::DuplicateSuggestion
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/agent_coaching_instruction.rb
Overview
The duplicate suggestion details.
Instance Attribute Summary collapse
-
#answer_record ⇒ ::String
readonly
Output only.
-
#similarity_score ⇒ ::Float
readonly
Output only.
-
#suggestion_index ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#answer_record ⇒ ::String (readonly)
Returns Output only. The answer record id of the past duplicate suggestion.
79 80 81 82 |
# File 'proto_docs/google/cloud/dialogflow/v2/agent_coaching_instruction.rb', line 79 class DuplicateSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#similarity_score ⇒ ::Float (readonly)
Returns Output only. The similarity score of between the past and current suggestion.
79 80 81 82 |
# File 'proto_docs/google/cloud/dialogflow/v2/agent_coaching_instruction.rb', line 79 class DuplicateSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#suggestion_index ⇒ ::Integer (readonly)
Returns Output only. The index of the duplicate suggestion in the past suggestion list.
79 80 81 82 |
# File 'proto_docs/google/cloud/dialogflow/v2/agent_coaching_instruction.rb', line 79 class DuplicateSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |