Class: Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/generator.rb
Overview
Duplication check for the suggestion.
Defined Under Namespace
Classes: DuplicateSuggestion
Instance Attribute Summary collapse
-
#duplicate_suggestions ⇒ ::Array<::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult::DuplicateSuggestion>
readonly
Output only.
Instance Attribute Details
#duplicate_suggestions ⇒ ::Array<::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult::DuplicateSuggestion> (readonly)
Returns Output only. The duplicate suggestions.
466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'proto_docs/google/cloud/dialogflow/v2/generator.rb', line 466 class DuplicateCheckResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The duplicate suggestion details. # Keeping answer_record and sources together as they are identifiers for # duplicate suggestions. # @!attribute [r] answer_record # @return [::String] # Output only. The answer record id of the past duplicate suggestion. # @!attribute [r] sources # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::Sources] # Output only. Sources for the suggestion. # @!attribute [r] suggestion_index # @return [::Integer] # Output only. The index of the duplicate suggestion in the past # suggestion list. # @!attribute [r] similarity_score # @return [::Float] # Output only. The similarity score of between the past and current # suggestion. class DuplicateSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |