Class: Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult::DuplicateSuggestion

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/generator.rb

Overview

The duplicate suggestion details. Keeping answer_record and sources together as they are identifiers for duplicate suggestions.

Instance Attribute Summary collapse

Instance Attribute Details

#answer_record::String (readonly)

Returns Output only. The answer record id of the past duplicate suggestion.

Returns:

  • (::String)

    Output only. The answer record id of the past duplicate suggestion.



487
488
489
490
# File 'proto_docs/google/cloud/dialogflow/v2/generator.rb', line 487

class DuplicateSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#similarity_score::Float (readonly)

Returns Output only. The similarity score of between the past and current suggestion.

Returns:

  • (::Float)

    Output only. The similarity score of between the past and current suggestion.



487
488
489
490
# File 'proto_docs/google/cloud/dialogflow/v2/generator.rb', line 487

class DuplicateSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sources::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::Sources (readonly)

Returns Output only. Sources for the suggestion.

Returns:



487
488
489
490
# File 'proto_docs/google/cloud/dialogflow/v2/generator.rb', line 487

class DuplicateSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#suggestion_index::Integer (readonly)

Returns Output only. The index of the duplicate suggestion in the past suggestion list.

Returns:

  • (::Integer)

    Output only. The index of the duplicate suggestion in the past suggestion list.



487
488
489
490
# File 'proto_docs/google/cloud/dialogflow/v2/generator.rb', line 487

class DuplicateSuggestion
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end