Class: Google::Cloud::Dialogflow::V2::AssistQueryParameters
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::AssistQueryParameters
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/participant.rb
Overview
Represents the parameters of human assist query.
Defined Under Namespace
Classes: DocumentsMetadataFiltersEntry
Instance Attribute Summary collapse
-
#documents_metadata_filters ⇒ ::Google::Protobuf::Map{::String => ::String}
Key-value filters on the metadata of documents returned by article suggestion.
Instance Attribute Details
#documents_metadata_filters ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Key-value filters on the metadata of documents returned by article suggestion. If specified, article suggestion only returns suggested documents that match all filters in their Document.metadata. Multiple values for a metadata key should be concatenated by comma. For example, filters to match all documents that have 'US' or 'CA' in their market metadata values and 'agent' in their user metadata values will be
documents_metadata_filters {
key: "market"
value: "US,CA"
}
documents_metadata_filters {
key: "user"
value: "agent"
}
```.
1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1179 class AssistQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DocumentsMetadataFiltersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |