Class: Google::Cloud::Dialogflow::V2::AutomatedAgentReply
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::AutomatedAgentReply
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/participant.rb
Overview
Represents a response from an automated agent.
Defined Under Namespace
Modules: AutomatedAgentReplyType
Instance Attribute Summary collapse
-
#allow_cancellation ⇒ ::Boolean
Indicates whether the partial automated agent reply is interruptible when a later reply message arrives.
-
#automated_agent_reply_type ⇒ ::Google::Cloud::Dialogflow::V2::AutomatedAgentReply::AutomatedAgentReplyType
AutomatedAgentReply type.
-
#cx_current_page ⇒ ::String
The unique identifier of the current Dialogflow CX conversation page.
-
#detect_intent_response ⇒ ::Google::Cloud::Dialogflow::V2::DetectIntentResponse
Response of the Dialogflow Sessions.DetectIntent call.
Instance Attribute Details
#allow_cancellation ⇒ ::Boolean
Returns Indicates whether the partial automated agent reply is interruptible when a later reply message arrives. e.g. if the agent specified some music as partial response, it can be cancelled.
870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 870 class AutomatedAgentReply include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents different automated agent reply types. module AutomatedAgentReplyType # Not specified. This should never happen. AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED = 0 # Partial reply. e.g. Aggregated responses in a `Fulfillment` that enables # `return_partial_response` can be returned as partial reply. # WARNING: partial reply is not eligible for barge-in. PARTIAL = 1 # Final reply. FINAL = 2 end end |
#automated_agent_reply_type ⇒ ::Google::Cloud::Dialogflow::V2::AutomatedAgentReply::AutomatedAgentReplyType
Returns AutomatedAgentReply type.
870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 870 class AutomatedAgentReply include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents different automated agent reply types. module AutomatedAgentReplyType # Not specified. This should never happen. AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED = 0 # Partial reply. e.g. Aggregated responses in a `Fulfillment` that enables # `return_partial_response` can be returned as partial reply. # WARNING: partial reply is not eligible for barge-in. PARTIAL = 1 # Final reply. FINAL = 2 end end |
#cx_current_page ⇒ ::String
Returns The unique identifier of the current Dialogflow CX conversation page.
Format: projects/<Project ID>/locations/<Location ID>/agents/<Agent
ID>/flows/<Flow ID>/pages/<Page ID>.
870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 870 class AutomatedAgentReply include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents different automated agent reply types. module AutomatedAgentReplyType # Not specified. This should never happen. AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED = 0 # Partial reply. e.g. Aggregated responses in a `Fulfillment` that enables # `return_partial_response` can be returned as partial reply. # WARNING: partial reply is not eligible for barge-in. PARTIAL = 1 # Final reply. FINAL = 2 end end |
#detect_intent_response ⇒ ::Google::Cloud::Dialogflow::V2::DetectIntentResponse
Returns Response of the Dialogflow Sessions.DetectIntent call.
870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 870 class AutomatedAgentReply include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents different automated agent reply types. module AutomatedAgentReplyType # Not specified. This should never happen. AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED = 0 # Partial reply. e.g. Aggregated responses in a `Fulfillment` that enables # `return_partial_response` can be returned as partial reply. # WARNING: partial reply is not eligible for barge-in. PARTIAL = 1 # Final reply. FINAL = 2 end end |