Class: Google::Cloud::Dialogflow::V2::CesAppSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/ces_app.rb

Overview

Spec of CES app that the generator can choose from.

Instance Attribute Summary collapse

Instance Attribute Details

#ces_app::String

Returns Optional. Format: projects/<Project ID>/locations/<Location ID>/apps/<app ID>.

Returns:

  • (::String)

    Optional. Format: projects/<Project ID>/locations/<Location ID>/apps/<app ID>.



44
45
46
47
# File 'proto_docs/google/cloud/dialogflow/v2/ces_app.rb', line 44

class CesAppSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#confirmation_requirement::Google::Cloud::Dialogflow::V2::Tool::ConfirmationRequirement

Returns Optional. Indicates whether the app requires human confirmation.

Returns:



44
45
46
47
# File 'proto_docs/google/cloud/dialogflow/v2/ces_app.rb', line 44

class CesAppSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#proactive_enabled::Boolean

Returns Optional. Only applicable for CompanionAgent. Indicates whether the ces app is enabled in proactive mode. At least one of proactive_enabled or reactive_enabled should be true; otherwise, the ces app will be ignored.

Returns:

  • (::Boolean)

    Optional. Only applicable for CompanionAgent. Indicates whether the ces app is enabled in proactive mode. At least one of proactive_enabled or reactive_enabled should be true; otherwise, the ces app will be ignored.



44
45
46
47
# File 'proto_docs/google/cloud/dialogflow/v2/ces_app.rb', line 44

class CesAppSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reactive_enabled::Boolean

Returns Optional. Only applicable for CompanionAgent. Indicates whether the ces app is enabled in reactive mode. At least one of proactive_enabled or reactive_enabled should be true; otherwise, the ces app will be ignored.

Returns:

  • (::Boolean)

    Optional. Only applicable for CompanionAgent. Indicates whether the ces app is enabled in reactive mode. At least one of proactive_enabled or reactive_enabled should be true; otherwise, the ces app will be ignored.



44
45
46
47
# File 'proto_docs/google/cloud/dialogflow/v2/ces_app.rb', line 44

class CesAppSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end