Class: Google::Cloud::Dialogflow::V2::CloudConversationDebuggingInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/session.rb

Overview

Cloud conversation info for easier debugging. It will get populated in StreamingDetectIntentResponse or StreamingAnalyzeContentResponse when the flag enable_debugging_info is set to true in corresponding requests.

Instance Attribute Summary collapse

Instance Attribute Details

#audio_data_chunks::Integer

Returns Number of input audio data chunks in streaming requests.

Returns:

  • Number of input audio data chunks in streaming requests.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#bargein_event_triggered::Boolean

Returns Whether a barge-in event is triggered in this request.

Returns:

  • Whether a barge-in event is triggered in this request.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#client_half_close_streaming_time_offset::Google::Protobuf::Duration

Returns Client half close time in terms of API streaming duration.

Returns:

  • Client half close time in terms of API streaming duration.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#client_half_close_time_offset::Google::Protobuf::Duration

Returns Client half close time in terms of input audio duration.

Returns:

  • Client half close time in terms of input audio duration.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#dtmf_final_results_times::Array<::Google::Protobuf::Duration>

Returns Time offsets of the DTMF final results relative to the beginning of the stream.

Returns:

  • Time offsets of the DTMF final results relative to the beginning of the stream.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#dtmf_partial_results_times::Array<::Google::Protobuf::Duration>

Returns Time offsets of the DTMF partial results relative to the beginning of the stream.

Returns:

  • Time offsets of the DTMF partial results relative to the beginning of the stream.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#endpointing_timeout::Google::Protobuf::Duration

Returns Speech endpointing timeout settings for the stream.

Returns:

  • Speech endpointing timeout settings for the stream.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#first_audio_duration::Google::Protobuf::Duration

Returns Duration of first audio chunk.

Returns:

  • Duration of first audio chunk.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_input_text::Boolean

Returns Whether the streaming terminates with an injected text query.

Returns:

  • Whether the streaming terminates with an injected text query.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#no_speech_timeout::Google::Protobuf::Duration

Returns No speech timeout settings for the stream.

Returns:

  • No speech timeout settings for the stream.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#partial_responses::Integer

Returns Total number of partial responses.

Returns:

  • Total number of partial responses.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#result_end_time_offset::Google::Protobuf::Duration

Returns Time offset of the end of speech utterance relative to the beginning of the first audio chunk.

Returns:

  • Time offset of the end of speech utterance relative to the beginning of the first audio chunk.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#single_utterance::Boolean

Returns Whether client used single utterance mode.

Returns:

  • Whether client used single utterance mode.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#single_utterance_end_time_offset::Google::Protobuf::Duration

Returns Time offset of the end-of-single-utterance signal relative to the beginning of the stream.

Returns:

  • Time offset of the end-of-single-utterance signal relative to the beginning of the stream.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#speaker_id_passive_latency_ms_offset::Integer

Returns Time offset of Speaker ID stream close time relative to the Speech stream close time in milliseconds. Only meaningful for conversations involving passive verification.

Returns:

  • Time offset of Speaker ID stream close time relative to the Speech stream close time in milliseconds. Only meaningful for conversations involving passive verification.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#speech_final_results_end_times::Array<::Google::Protobuf::Duration>

Returns Time offsets of the speech final results (is_final=true) relative to the beginning of the stream.

Returns:

  • Time offsets of the speech final results (is_final=true) relative to the beginning of the stream.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#speech_partial_results_end_times::Array<::Google::Protobuf::Duration>

Returns Time offsets of the speech partial results relative to the beginning of the stream.

Returns:

  • Time offsets of the speech partial results relative to the beginning of the stream.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#speech_single_utterance::Boolean

Returns Whether speech uses single utterance mode.

Returns:

  • Whether speech uses single utterance mode.



495
496
497
498
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 495

class CloudConversationDebuggingInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end