Class: Google::Cloud::Dialogflow::V2::Conversation::ContextReference::ContextContent
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::Conversation::ContextReference::ContextContent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/conversation.rb
Overview
Contents ingested.
Defined Under Namespace
Modules: ContentFormat
Instance Attribute Summary collapse
-
#answer_record ⇒ ::String
If the context content was generated from a tool call, specify the answer record associated with the tool call.
-
#content ⇒ ::String
Required.
-
#content_format ⇒ ::Google::Cloud::Dialogflow::V2::Conversation::ContextReference::ContextContent::ContentFormat
Required.
-
#ingestion_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#answer_record ⇒ ::String
Returns If the context content was generated from a tool call, specify the
answer record associated with the tool call.
Format: projects/<Project ID>/locations/<Location
ID>/answerRecords/<Answer Record ID>.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 169 class ContextContent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the format of the ingested string. module ContentFormat # Unspecified content format. CONTENT_FORMAT_UNSPECIFIED = 0 # Content was provided in JSON format. JSON = 1 # Content was provided as plain text. PLAIN_TEXT = 2 end end |
#content ⇒ ::String
Returns Required. The information ingested in a single request.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 169 class ContextContent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the format of the ingested string. module ContentFormat # Unspecified content format. CONTENT_FORMAT_UNSPECIFIED = 0 # Content was provided in JSON format. JSON = 1 # Content was provided as plain text. PLAIN_TEXT = 2 end end |
#content_format ⇒ ::Google::Cloud::Dialogflow::V2::Conversation::ContextReference::ContextContent::ContentFormat
Returns Required. The format of the ingested string.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 169 class ContextContent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the format of the ingested string. module ContentFormat # Unspecified content format. CONTENT_FORMAT_UNSPECIFIED = 0 # Content was provided in JSON format. JSON = 1 # Content was provided as plain text. PLAIN_TEXT = 2 end end |
#ingestion_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when this information was incorporated into the relevant context reference.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 169 class ContextContent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the format of the ingested string. module ContentFormat # Unspecified content format. CONTENT_FORMAT_UNSPECIFIED = 0 # Content was provided in JSON format. JSON = 1 # Content was provided as plain text. PLAIN_TEXT = 2 end end |