Class: Google::Cloud::Dialogflow::V2::Conversation::TelephonyConnectionInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/conversation.rb

Overview

The information about phone calls connected via phone gateway to the conversation.

Defined Under Namespace

Classes: MimeContent, SipHeader

Instance Attribute Summary collapse

Instance Attribute Details

#dialed_number::String (readonly)

Returns Output only. The number dialed to connect this call in E.164 format.

Returns:

  • (::String)

    Output only. The number dialed to connect this call in E.164 format.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 105

class TelephonyConnectionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The SIP headers from the initial SIP INVITE.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. The name of the header.
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value of the header.
  class SipHeader
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The mime content from the initial SIP INVITE.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Optional. The mime type of the content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Optional. The content payload.
  class MimeContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#extra_mime_contents::Array<::Google::Cloud::Dialogflow::V2::Conversation::TelephonyConnectionInfo::MimeContent> (readonly)

Returns Output only. The mime content from the initial SIP INVITE.

Returns:



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 105

class TelephonyConnectionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The SIP headers from the initial SIP INVITE.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. The name of the header.
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value of the header.
  class SipHeader
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The mime content from the initial SIP INVITE.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Optional. The mime type of the content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Optional. The content payload.
  class MimeContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#sdp::String

Returns Optional. SDP of the call. It's initially the SDP answer to the incoming call, but maybe later updated for the purpose of making the link active, etc.

Returns:

  • (::String)

    Optional. SDP of the call. It's initially the SDP answer to the incoming call, but maybe later updated for the purpose of making the link active, etc.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 105

class TelephonyConnectionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The SIP headers from the initial SIP INVITE.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. The name of the header.
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value of the header.
  class SipHeader
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The mime content from the initial SIP INVITE.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Optional. The mime type of the content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Optional. The content payload.
  class MimeContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#sip_headers::Array<::Google::Cloud::Dialogflow::V2::Conversation::TelephonyConnectionInfo::SipHeader> (readonly)

Returns Output only. The SIP headers from the initial SIP INVITE.

Returns:



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 105

class TelephonyConnectionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The SIP headers from the initial SIP INVITE.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. The name of the header.
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value of the header.
  class SipHeader
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The mime content from the initial SIP INVITE.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Optional. The mime type of the content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Optional. The content payload.
  class MimeContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end