Module: Google::Cloud::Dialogflow::V2::DatastoreResponseReason

Defined in:
proto_docs/google/cloud/dialogflow/v2/participant.rb

Overview

Response reason from datastore which indicates data serving status or answer quality degradation.

Constant Summary collapse

DATASTORE_RESPONSE_REASON_UNSPECIFIED =

Default value.

0
NONE =

No specific response reason from datastore.

1
SEARCH_OUT_OF_QUOTA =

Search is blocked due to out of quota.

2
SEARCH_EMPTY_RESULTS =

Search returns empty results.

3
ANSWER_GENERATION_GEN_AI_DISABLED =

Generative AI is disabled.

4
ANSWER_GENERATION_OUT_OF_QUOTA =

Answer generation is blocked due to out of quota.

5
ANSWER_GENERATION_ERROR =

Answer generation encounters an error.

6
ANSWER_GENERATION_NOT_ENOUGH_INFO =

Answer generation does not have enough information to generate answer.

7
ANSWER_GENERATION_RAI_FAILED =

Answer generation is blocked by RAI (Responsible AI) failure.

8
ANSWER_GENERATION_NOT_GROUNDED =

Answer generation is not grounded on reliable sources.

9