Class: Google::Cloud::Dialogflow::V2::GenerateStatelessSuggestionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/conversation.rb

Overview

Defined Under Namespace

Classes: ContextReferencesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#context_references::Google::Protobuf::Map{::String => ::Google::Cloud::Dialogflow::V2::Conversation::ContextReference}

Returns Optional. A section of ingested context information. The key is the name of the context reference and the value contains the contents of the context reference. The key is used to incorporate ingested context references to enhance the generator.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::Dialogflow::V2::Conversation::ContextReference})

    Optional. A section of ingested context information. The key is the name of the context reference and the value contains the contents of the context reference. The key is used to incorporate ingested context references to enhance the generator.



712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 712

class GenerateStatelessSuggestionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::V2::Conversation::ContextReference]
  class ContextReferencesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#conversation_context::Google::Cloud::Dialogflow::V2::ConversationContext

Returns Optional. Context of the conversation, including transcripts.

Returns:



712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 712

class GenerateStatelessSuggestionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::V2::Conversation::ContextReference]
  class ContextReferencesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#generator::Google::Cloud::Dialogflow::V2::Generator

Returns Uncreated generator. It should be a complete generator that includes all information about the generator.

Note: The following fields are mutually exclusive: generator, generator_name. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dialogflow::V2::Generator)

    Uncreated generator. It should be a complete generator that includes all information about the generator.

    Note: The following fields are mutually exclusive: generator, generator_name. If a field in that set is populated, all other fields in the set will automatically be cleared.



712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 712

class GenerateStatelessSuggestionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::V2::Conversation::ContextReference]
  class ContextReferencesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#generator_name::String

Returns The resource name of the existing created generator. Format: projects/<Project ID>/locations/<Location ID>/generators/<Generator ID>

Note: The following fields are mutually exclusive: generator_name, generator. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The resource name of the existing created generator. Format: projects/<Project ID>/locations/<Location ID>/generators/<Generator ID>

    Note: The following fields are mutually exclusive: generator_name, generator. If a field in that set is populated, all other fields in the set will automatically be cleared.



712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 712

class GenerateStatelessSuggestionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::V2::Conversation::ContextReference]
  class ContextReferencesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#parent::String

Returns Required. The parent resource to charge for the Suggestion's generation. Format: projects/<Project ID>/locations/<Location ID>.

Returns:

  • (::String)

    Required. The parent resource to charge for the Suggestion's generation. Format: projects/<Project ID>/locations/<Location ID>.



712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 712

class GenerateStatelessSuggestionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::V2::Conversation::ContextReference]
  class ContextReferencesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#security_settings::String

Returns Optional. Name of the CX SecuritySettings which is used to redact generated response. If this field is empty, try to fetch v2 security_settings, which is a project level setting. If this field is empty and no v2 security_settings set up in this project, no redaction will be done.

Format: projects/<Project ID>/locations/<Location ID>/securitySettings/<Security Settings ID>.

Returns:

  • (::String)

    Optional. Name of the CX SecuritySettings which is used to redact generated response. If this field is empty, try to fetch v2 security_settings, which is a project level setting. If this field is empty and no v2 security_settings set up in this project, no redaction will be done.

    Format: projects/<Project ID>/locations/<Location ID>/securitySettings/<Security Settings ID>.



712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 712

class GenerateStatelessSuggestionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::V2::Conversation::ContextReference]
  class ContextReferencesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#trigger_events::Array<::Google::Cloud::Dialogflow::V2::TriggerEvent>

Returns Optional. A list of trigger events. Generator will be triggered only if it's trigger event is included here.

Returns:



712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 712

class GenerateStatelessSuggestionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::V2::Conversation::ContextReference]
  class ContextReferencesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end