Class: Google::Cloud::Dialogflow::V2::GenerateStatelessSummaryRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/conversation.rb

Overview

The request message for Conversations.GenerateStatelessSummary.

Defined Under Namespace

Classes: MinimalConversation

Instance Attribute Summary collapse

Instance Attribute Details

#conversation_profile::Google::Cloud::Dialogflow::V2::ConversationProfile

Returns Required. A ConversationProfile containing information required for Summary generation. Required fields: {language_code, security_settings} Optional fields: {agent_assistant_config}.

Returns:



598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 598

class GenerateStatelessSummaryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum amount of information required to generate a Summary without
  # having a Conversation resource created.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Dialogflow::V2::Message>]
  #     Required. The messages that the Summary will be generated from. It is
  #     expected that this message content is already redacted and does not
  #     contain any PII. Required fields: {content, language_code, participant,
  #     participant_role} Optional fields: \\{send_time} If send_time is not
  #     provided, then the messages must be provided in chronological order.
  # @!attribute [rw] parent
  #   @return [::String]
  #     Required. The parent resource to charge for the Summary's generation.
  #     Format: `projects/<Project ID>/locations/<Location ID>`.
  class MinimalConversation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#latest_message::String

Returns Optional. The name of the latest conversation message used as context for generating a Summary. If empty, the latest message of the conversation will be used. The format is specific to the user and the names of the messages provided.

Returns:

  • (::String)

    Optional. The name of the latest conversation message used as context for generating a Summary. If empty, the latest message of the conversation will be used. The format is specific to the user and the names of the messages provided.



598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 598

class GenerateStatelessSummaryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum amount of information required to generate a Summary without
  # having a Conversation resource created.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Dialogflow::V2::Message>]
  #     Required. The messages that the Summary will be generated from. It is
  #     expected that this message content is already redacted and does not
  #     contain any PII. Required fields: {content, language_code, participant,
  #     participant_role} Optional fields: \\{send_time} If send_time is not
  #     provided, then the messages must be provided in chronological order.
  # @!attribute [rw] parent
  #   @return [::String]
  #     Required. The parent resource to charge for the Summary's generation.
  #     Format: `projects/<Project ID>/locations/<Location ID>`.
  class MinimalConversation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#max_context_size::Integer

Returns Optional. Max number of messages prior to and including [latest_message] to use as context when compiling the suggestion. By default 500 and at most 1000.

Returns:

  • (::Integer)

    Optional. Max number of messages prior to and including [latest_message] to use as context when compiling the suggestion. By default 500 and at most 1000.



598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 598

class GenerateStatelessSummaryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum amount of information required to generate a Summary without
  # having a Conversation resource created.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Dialogflow::V2::Message>]
  #     Required. The messages that the Summary will be generated from. It is
  #     expected that this message content is already redacted and does not
  #     contain any PII. Required fields: {content, language_code, participant,
  #     participant_role} Optional fields: \\{send_time} If send_time is not
  #     provided, then the messages must be provided in chronological order.
  # @!attribute [rw] parent
  #   @return [::String]
  #     Required. The parent resource to charge for the Summary's generation.
  #     Format: `projects/<Project ID>/locations/<Location ID>`.
  class MinimalConversation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#stateless_conversation::Google::Cloud::Dialogflow::V2::GenerateStatelessSummaryRequest::MinimalConversation

Returns Required. The conversation to suggest a summary for.

Returns:



598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 598

class GenerateStatelessSummaryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The minimum amount of information required to generate a Summary without
  # having a Conversation resource created.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Dialogflow::V2::Message>]
  #     Required. The messages that the Summary will be generated from. It is
  #     expected that this message content is already redacted and does not
  #     contain any PII. Required fields: {content, language_code, participant,
  #     participant_role} Optional fields: \\{send_time} If send_time is not
  #     provided, then the messages must be provided in chronological order.
  # @!attribute [rw] parent
  #   @return [::String]
  #     Required. The parent resource to charge for the Summary's generation.
  #     Format: `projects/<Project ID>/locations/<Location ID>`.
  class MinimalConversation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end