Class: Google::Cloud::Dialogflow::V2::GenerateSuggestionsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::GenerateSuggestionsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/participant.rb
Overview
The response message for Conversations.GenerateSuggestions.
Defined Under Namespace
Classes: GeneratorSuggestionAnswer
Instance Attribute Summary collapse
-
#generator_suggestion_answers ⇒ ::Array<::Google::Cloud::Dialogflow::V2::GenerateSuggestionsResponse::GeneratorSuggestionAnswer>
The answers generated for the conversation based on context.
-
#latest_message ⇒ ::String
The name of the latest conversation message used as context for compiling suggestion.
Instance Attribute Details
#generator_suggestion_answers ⇒ ::Array<::Google::Cloud::Dialogflow::V2::GenerateSuggestionsResponse::GeneratorSuggestionAnswer>
Returns The answers generated for the conversation based on context.
736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 736 class GenerateSuggestionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A GeneratorSuggestion answer. # @!attribute [rw] generator_suggestion # @return [::Google::Cloud::Dialogflow::V2::GeneratorSuggestion] # Suggestion details. # @!attribute [rw] source_generator # @return [::String] # The name of the generator used to generate this suggestion. Format: # `projects/<Project ID>/locations/<Location ID>/generators/<Generator # ID>`. # @!attribute [rw] answer_record # @return [::String] # Answer record that uniquely identifies the suggestion. This can be used # to provide suggestion feedback. class GeneratorSuggestionAnswer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#latest_message ⇒ ::String
Returns The name of the latest conversation message used as context for compiling suggestion.
Format: projects/<Project ID>/locations/<Location
ID>/conversations/<Conversation ID>/messages/<Message ID>.
736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 736 class GenerateSuggestionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A GeneratorSuggestion answer. # @!attribute [rw] generator_suggestion # @return [::Google::Cloud::Dialogflow::V2::GeneratorSuggestion] # Suggestion details. # @!attribute [rw] source_generator # @return [::String] # The name of the generator used to generate this suggestion. Format: # `projects/<Project ID>/locations/<Location ID>/generators/<Generator # ID>`. # @!attribute [rw] answer_record # @return [::String] # Answer record that uniquely identifies the suggestion. This can be used # to provide suggestion feedback. class GeneratorSuggestionAnswer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |