Class: Google::Cloud::Dialogflow::V2::HumanAgentAssistantConfig::SuggestionQueryConfig::Sections
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::HumanAgentAssistantConfig::SuggestionQueryConfig::Sections
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb
Overview
Custom sections to return when requesting a summary of a conversation.
This is only supported when baseline_model_version == '2.0'.
Supported features: CONVERSATION_SUMMARIZATION, CONVERSATION_SUMMARIZATION_VOICE.
Defined Under Namespace
Modules: SectionType
Instance Attribute Summary collapse
-
#section_types ⇒ ::Array<::Google::Cloud::Dialogflow::V2::HumanAgentAssistantConfig::SuggestionQueryConfig::Sections::SectionType>
The selected sections chosen to return when requesting a summary of a conversation.
Instance Attribute Details
#section_types ⇒ ::Array<::Google::Cloud::Dialogflow::V2::HumanAgentAssistantConfig::SuggestionQueryConfig::Sections::SectionType>
Returns The selected sections chosen to return when requesting a summary of a conversation. A duplicate selected section will be treated as a single selected section. If section types are not provided, the default will be {SITUATION, ACTION, RESULT}.
531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb', line 531 class Sections include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Selectable sections to return when requesting a summary of a # conversation. module SectionType # Undefined section type, does not return anything. SECTION_TYPE_UNSPECIFIED = 0 # What the customer needs help with or has question about. # Section name: "situation". SITUATION = 1 # What the agent does to help the customer. # Section name: "action". ACTION = 2 # Result of the customer service. A single word describing the result # of the conversation. # Section name: "resolution". RESOLUTION = 3 # Reason for cancellation if the customer requests for a cancellation. # "N/A" otherwise. # Section name: "reason_for_cancellation". REASON_FOR_CANCELLATION = 4 # "Unsatisfied" or "Satisfied" depending on the customer's feelings at # the end of the conversation. # Section name: "customer_satisfaction". CUSTOMER_SATISFACTION = 5 # Key entities extracted from the conversation, such as ticket number, # order number, dollar amount, etc. # Section names are prefixed by "entities/". ENTITIES = 6 end end |