Class: Google::Cloud::Dialogflow::V2::IngestContextReferencesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/conversation.rb

Overview

The request message for [ConversationsService.IngestContextReferences][].

Defined Under Namespace

Classes: ContextReferencesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#context_references::Google::Protobuf::Map{::String => ::Google::Cloud::Dialogflow::V2::Conversation::ContextReference}

Returns Required. The context references to ingest. The key is the name of the context reference and the value contains the contents of the context reference. The key is used to incorporate ingested context references to enhance the generator.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::Dialogflow::V2::Conversation::ContextReference})

    Required. The context references to ingest. The key is the name of the context reference and the value contains the contents of the context reference. The key is used to incorporate ingested context references to enhance the generator.



443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 443

class IngestContextReferencesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::V2::Conversation::ContextReference]
  class ContextReferencesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#conversation::String

Returns Required. Resource identifier of the conversation to ingest context information for. Format: projects/<Project ID>/locations/<Location ID>/conversations/<Conversation ID>.

Returns:

  • (::String)

    Required. Resource identifier of the conversation to ingest context information for. Format: projects/<Project ID>/locations/<Location ID>/conversations/<Conversation ID>.



443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 443

class IngestContextReferencesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dialogflow::V2::Conversation::ContextReference]
  class ContextReferencesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end