Module: Google::Cloud::Dialogflow::V2::IngestedContextReferenceDebugInfo::IngestedParameterDebugInfo::IngestionStatus

Defined in:
proto_docs/google/cloud/dialogflow/v2/participant.rb

Overview

Enum representing the various states of parameter ingestion.

Constant Summary collapse

INGESTION_STATUS_UNSPECIFIED =

Default value, indicates that the ingestion status is not specified.

0
INGESTION_STATUS_SUCCEEDED =

Indicates that the parameter was successfully ingested.

1
INGESTION_STATUS_CONTEXT_NOT_AVAILABLE =

Indicates that the parameter was not available for ingestion.

2
INGESTION_STATUS_PARSE_FAILED =

Indicates that there was a failure parsing the parameter content.

3
INGESTION_STATUS_INVALID_ENTRY =

Indicates that the context reference had an unexpected number of content entries as Context reference should only have one entry.

4
INGESTION_STATUS_INVALID_FORMAT =

Indicates that the context reference content was not in the expected format (e.g., JSON).

5
INGESTION_STATUS_LANGUAGE_MISMATCH =

Indicates that the context reference language does not match the conversation language.

6