Class: Google::Cloud::Dialogflow::V2::Intent::Message::ColumnProperties
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::Intent::Message::ColumnProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/intent.rb
Overview
Column properties for TableCard.
Defined Under Namespace
Modules: HorizontalAlignment
Instance Attribute Summary collapse
-
#header ⇒ ::String
Required.
-
#horizontal_alignment ⇒ ::Google::Cloud::Dialogflow::V2::Intent::Message::ColumnProperties::HorizontalAlignment
Optional.
Instance Attribute Details
#header ⇒ ::String
770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 |
# File 'proto_docs/google/cloud/dialogflow/v2/intent.rb', line 770 class ColumnProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Text alignments within a cell. module HorizontalAlignment # Text is aligned to the leading edge of the column. HORIZONTAL_ALIGNMENT_UNSPECIFIED = 0 # Text is aligned to the leading edge of the column. LEADING = 1 # Text is centered in the column. CENTER = 2 # Text is aligned to the trailing edge of the column. TRAILING = 3 end end |
#horizontal_alignment ⇒ ::Google::Cloud::Dialogflow::V2::Intent::Message::ColumnProperties::HorizontalAlignment
770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 |
# File 'proto_docs/google/cloud/dialogflow/v2/intent.rb', line 770 class ColumnProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Text alignments within a cell. module HorizontalAlignment # Text is aligned to the leading edge of the column. HORIZONTAL_ALIGNMENT_UNSPECIFIED = 0 # Text is aligned to the leading edge of the column. LEADING = 1 # Text is centered in the column. CENTER = 2 # Text is aligned to the trailing edge of the column. TRAILING = 3 end end |