Class: Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/participant.rb

Overview

Details about source of Generative answer.

Defined Under Namespace

Classes: Snippet

Instance Attribute Summary collapse

Instance Attribute Details

#snippets::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource::Snippet>

Returns All snippets used for this Generative Prediction, with their source URI and data.

Returns:

  • All snippets used for this Generative Prediction, with their source URI and data.



1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1300

class GenerativeSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Snippet Source for a Generative Prediction.
  # @!attribute [rw] uri
  #   @return [::String]
  #     URI the data is sourced from.
  # @!attribute [rw] text
  #   @return [::String]
  #     Text taken from that URI.
  # @!attribute [rw] title
  #   @return [::String]
  #     Title of the document.
  # @!attribute [rw] metadata
  #   @return [::Google::Protobuf::Struct]
  #     Metadata of the document.
  class Snippet
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end