Class: Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::SuggestedQuery

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/participant.rb

Overview

Represents a suggested query.

Defined Under Namespace

Classes: SearchContext

Instance Attribute Summary collapse

Instance Attribute Details

#query_text::String

Returns Suggested query text.

Returns:

  • (::String)

    Suggested query text.



1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1536

class SuggestedQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Search context is information useful for knowledge search that helps
  # enrich the query.
  # Example:
  # search_context {
  #   key: "application name"
  #   value: "DesignApp"
  # }
  # @!attribute [rw] key
  #   @return [::String]
  #     Optional. The key of the search context, e.g. "application name".
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value of the search context, e.g. "DesignApp".
  class SearchContext
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#search_contexts::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::SuggestedQuery::SearchContext>

Returns Optional. The search contexts for the query.

Returns:



1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1536

class SuggestedQuery
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Search context is information useful for knowledge search that helps
  # enrich the query.
  # Example:
  # search_context {
  #   key: "application name"
  #   value: "DesignApp"
  # }
  # @!attribute [rw] key
  #   @return [::String]
  #     Optional. The key of the search context, e.g. "application name".
  # @!attribute [rw] value
  #   @return [::String]
  #     Optional. The value of the search context, e.g. "DesignApp".
  class SearchContext
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end