Class: Google::Cloud::Dialogflow::V2::MessageEntry
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::MessageEntry
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/generator.rb
Overview
Represents a message entry of a conversation.
Defined Under Namespace
Modules: Role
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#language_code ⇒ ::String
Optional.
-
#role ⇒ ::Google::Cloud::Dialogflow::V2::MessageEntry::Role
Optional.
-
#text ⇒ ::String
Optional.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'proto_docs/google/cloud/dialogflow/v2/generator.rb', line 127 class MessageEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of the roles a participant can play in a conversation. module Role # Participant role not set. ROLE_UNSPECIFIED = 0 # Participant is a human agent. HUMAN_AGENT = 1 # Participant is an automated agent, such as a Dialogflow agent. AUTOMATED_AGENT = 2 # Participant is an end user that has called or chatted with # Dialogflow services. END_USER = 3 end end |
#language_code ⇒ ::String
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'proto_docs/google/cloud/dialogflow/v2/generator.rb', line 127 class MessageEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of the roles a participant can play in a conversation. module Role # Participant role not set. ROLE_UNSPECIFIED = 0 # Participant is a human agent. HUMAN_AGENT = 1 # Participant is an automated agent, such as a Dialogflow agent. AUTOMATED_AGENT = 2 # Participant is an end user that has called or chatted with # Dialogflow services. END_USER = 3 end end |
#role ⇒ ::Google::Cloud::Dialogflow::V2::MessageEntry::Role
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'proto_docs/google/cloud/dialogflow/v2/generator.rb', line 127 class MessageEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of the roles a participant can play in a conversation. module Role # Participant role not set. ROLE_UNSPECIFIED = 0 # Participant is a human agent. HUMAN_AGENT = 1 # Participant is an automated agent, such as a Dialogflow agent. AUTOMATED_AGENT = 2 # Participant is an end user that has called or chatted with # Dialogflow services. END_USER = 3 end end |
#text ⇒ ::String
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'proto_docs/google/cloud/dialogflow/v2/generator.rb', line 127 class MessageEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of the roles a participant can play in a conversation. module Role # Participant role not set. ROLE_UNSPECIFIED = 0 # Participant is a human agent. HUMAN_AGENT = 1 # Participant is an automated agent, such as a Dialogflow agent. AUTOMATED_AGENT = 2 # Participant is an end user that has called or chatted with # Dialogflow services. END_USER = 3 end end |