Class: Google::Cloud::Dialogflow::V2::NotificationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb

Overview

Defines notification behavior.

Defined Under Namespace

Modules: MessageFormat

Instance Attribute Summary collapse

Instance Attribute Details

#message_format::Google::Cloud::Dialogflow::V2::NotificationConfig::MessageFormat

Returns Format of message.



740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
# File 'proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb', line 740

class NotificationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Format of cloud pub/sub message.
  module MessageFormat
    # If it is unspecified, PROTO will be used.
    MESSAGE_FORMAT_UNSPECIFIED = 0

    # Pub/Sub message will be serialized proto.
    PROTO = 1

    # Pub/Sub message will be json.
    JSON = 2
  end
end

#topic::String

Returns Name of the Pub/Sub topic to publish conversation events like CONVERSATION_STARTED as serialized ConversationEvent protos.

For telephony integration to receive notification, make sure either this topic is in the same project as the conversation or you grant service-<Conversation Project Number>@gcp-sa-dialogflow.iam.gserviceaccount.com the Dialogflow Service Agent role in the topic project.

For chat integration to receive notification, make sure API caller has been granted the Dialogflow Service Agent role for the topic.

Format: projects/<Project ID>/locations/<Location ID>/topics/<Topic ID>.

Returns:

  • (::String)

    Name of the Pub/Sub topic to publish conversation events like CONVERSATION_STARTED as serialized ConversationEvent protos.

    For telephony integration to receive notification, make sure either this topic is in the same project as the conversation or you grant service-<Conversation Project Number>@gcp-sa-dialogflow.iam.gserviceaccount.com the Dialogflow Service Agent role in the topic project.

    For chat integration to receive notification, make sure API caller has been granted the Dialogflow Service Agent role for the topic.

    Format: projects/<Project ID>/locations/<Location ID>/topics/<Topic ID>.



740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
# File 'proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb', line 740

class NotificationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Format of cloud pub/sub message.
  module MessageFormat
    # If it is unspecified, PROTO will be used.
    MESSAGE_FORMAT_UNSPECIFIED = 0

    # Pub/Sub message will be serialized proto.
    PROTO = 1

    # Pub/Sub message will be json.
    JSON = 2
  end
end