Class: Google::Cloud::Dialogflow::V2::SearchKnowledgeDebugInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::SearchKnowledgeDebugInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/conversation.rb
Overview
Debug information related to SearchKnowledge feature.
Defined Under Namespace
Classes: SearchKnowledgeBehavior
Instance Attribute Summary collapse
-
#ces_debug_info ⇒ ::Google::Protobuf::Struct
Optional.
-
#datastore_response_reason ⇒ ::Google::Cloud::Dialogflow::V2::DatastoreResponseReason
Response reason from datastore which indicates data serving status or answer quality degradation.
-
#ingested_context_reference_debug_info ⇒ ::Google::Cloud::Dialogflow::V2::IngestedContextReferenceDebugInfo
Information about parameters ingested for search knowledge.
-
#search_knowledge_behavior ⇒ ::Google::Cloud::Dialogflow::V2::SearchKnowledgeDebugInfo::SearchKnowledgeBehavior
Configured behaviors for SearchKnowledge.
-
#service_latency ⇒ ::Google::Cloud::Dialogflow::V2::ServiceLatency
The latency of the service.
Instance Attribute Details
#ces_debug_info ⇒ ::Google::Protobuf::Struct
Returns Optional. Debug info from the Customer Engagement Suite (CES) execution.
1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1028 class SearchKnowledgeDebugInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configured behaviors for SearchKnowledge. # @!attribute [rw] answer_generation_rewriter_on # @return [::Boolean] # Whether data store agent rewriter was turned on for the request. # @!attribute [rw] end_user_metadata_included # @return [::Boolean] # Whether end_user_metadata is included in the data store agent call. # @!attribute [rw] third_party_connector_allowed # @return [::Boolean] # This field indicates whether third party connectors are enabled for the # project. Note that this field only indicates if the project is # allowlisted for connectors. class SearchKnowledgeBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#datastore_response_reason ⇒ ::Google::Cloud::Dialogflow::V2::DatastoreResponseReason
Returns Response reason from datastore which indicates data serving status or answer quality degradation.
1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1028 class SearchKnowledgeDebugInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configured behaviors for SearchKnowledge. # @!attribute [rw] answer_generation_rewriter_on # @return [::Boolean] # Whether data store agent rewriter was turned on for the request. # @!attribute [rw] end_user_metadata_included # @return [::Boolean] # Whether end_user_metadata is included in the data store agent call. # @!attribute [rw] third_party_connector_allowed # @return [::Boolean] # This field indicates whether third party connectors are enabled for the # project. Note that this field only indicates if the project is # allowlisted for connectors. class SearchKnowledgeBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ingested_context_reference_debug_info ⇒ ::Google::Cloud::Dialogflow::V2::IngestedContextReferenceDebugInfo
Returns Information about parameters ingested for search knowledge.
1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1028 class SearchKnowledgeDebugInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configured behaviors for SearchKnowledge. # @!attribute [rw] answer_generation_rewriter_on # @return [::Boolean] # Whether data store agent rewriter was turned on for the request. # @!attribute [rw] end_user_metadata_included # @return [::Boolean] # Whether end_user_metadata is included in the data store agent call. # @!attribute [rw] third_party_connector_allowed # @return [::Boolean] # This field indicates whether third party connectors are enabled for the # project. Note that this field only indicates if the project is # allowlisted for connectors. class SearchKnowledgeBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#search_knowledge_behavior ⇒ ::Google::Cloud::Dialogflow::V2::SearchKnowledgeDebugInfo::SearchKnowledgeBehavior
Returns Configured behaviors for SearchKnowledge.
1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1028 class SearchKnowledgeDebugInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configured behaviors for SearchKnowledge. # @!attribute [rw] answer_generation_rewriter_on # @return [::Boolean] # Whether data store agent rewriter was turned on for the request. # @!attribute [rw] end_user_metadata_included # @return [::Boolean] # Whether end_user_metadata is included in the data store agent call. # @!attribute [rw] third_party_connector_allowed # @return [::Boolean] # This field indicates whether third party connectors are enabled for the # project. Note that this field only indicates if the project is # allowlisted for connectors. class SearchKnowledgeBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#service_latency ⇒ ::Google::Cloud::Dialogflow::V2::ServiceLatency
Returns The latency of the service.
1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1028 class SearchKnowledgeDebugInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configured behaviors for SearchKnowledge. # @!attribute [rw] answer_generation_rewriter_on # @return [::Boolean] # Whether data store agent rewriter was turned on for the request. # @!attribute [rw] end_user_metadata_included # @return [::Boolean] # Whether end_user_metadata is included in the data store agent call. # @!attribute [rw] third_party_connector_allowed # @return [::Boolean] # This field indicates whether third party connectors are enabled for the # project. Note that this field only indicates if the project is # allowlisted for connectors. class SearchKnowledgeBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |