Module: Google::Cloud::Dialogflow::V2::SessionEntityType::EntityOverrideMode
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/session_entity_type.rb
Overview
The types of modifications for a session entity type.
Constant Summary collapse
- ENTITY_OVERRIDE_MODE_UNSPECIFIED =
Not specified. This value should be never used.
0- ENTITY_OVERRIDE_MODE_OVERRIDE =
The collection of session entities overrides the collection of entities in the corresponding custom entity type.
1- ENTITY_OVERRIDE_MODE_SUPPLEMENT =
The collection of session entities extends the collection of entities in the corresponding custom entity type.
Note: Even in this override mode calls to
ListSessionEntityTypes,GetSessionEntityType,CreateSessionEntityTypeandUpdateSessionEntityTypeonly return the additional entities added in this session entity type. If you want to get the supplemented list, please call EntityTypes.GetEntityType on the custom entity type and merge. 2