Class: Google::Cloud::Dialogflow::V2::SipTrunk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/sip_trunk.rb

Overview

SipTrunk is the resource that represents a SIP trunk to connect to Google Telephony platform SIP trunking service.

Instance Attribute Summary collapse

Instance Attribute Details

#connections::Array<::Google::Cloud::Dialogflow::V2::Connection> (readonly)

Returns Output only. Connections of the SIP trunk.

Returns:



125
126
127
128
# File 'proto_docs/google/cloud/dialogflow/v2/sip_trunk.rb', line 125

class SipTrunk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Optional. Human readable alias for this trunk.

Returns:

  • (::String)

    Optional. Human readable alias for this trunk.



125
126
127
128
# File 'proto_docs/google/cloud/dialogflow/v2/sip_trunk.rb', line 125

class SipTrunk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#expected_hostname::Array<::String>

Returns Required. The expected hostnames in the peer certificate from partner that is used for TLS authentication.

Returns:

  • (::Array<::String>)

    Required. The expected hostnames in the peer certificate from partner that is used for TLS authentication.



125
126
127
128
# File 'proto_docs/google/cloud/dialogflow/v2/sip_trunk.rb', line 125

class SipTrunk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The unique identifier of the SIP trunk. Format: projects/<Project ID>/locations/<Location ID>/sipTrunks/<SipTrunk ID>.

Returns:

  • (::String)

    Identifier. The unique identifier of the SIP trunk. Format: projects/<Project ID>/locations/<Location ID>/sipTrunks/<SipTrunk ID>.



125
126
127
128
# File 'proto_docs/google/cloud/dialogflow/v2/sip_trunk.rb', line 125

class SipTrunk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end