Class: Google::Cloud::Dialogflow::V2::StreamingDetectIntentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/session.rb

Overview

The top-level message sent by the client to the Sessions.StreamingDetectIntent method.

Multiple request messages should be sent in order:

  1. The first message must contain session, query_input plus optionally query_params. If the client wants to receive an audio response, it should also contain output_audio_config. The message must not contain input_audio.
  2. If query_input was set to query_input.audio_config, all subsequent messages must contain input_audio to continue with Speech recognition. If you decide to rather detect an intent from text input after you already started Speech recognition, please send a message with query_input.text.

    However, note that:

* Dialogflow will bill you for the audio duration so far.
* Dialogflow discards all Speech recognition results in favor of the
  input text.
* Dialogflow will use the language code from the first message.

After you sent all input, you must half-close or abort the request stream.

Instance Attribute Summary collapse

Instance Attribute Details

#input_audio::String



410
411
412
413
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 410

class StreamingDetectIntentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#output_audio_config::Google::Cloud::Dialogflow::V2::OutputAudioConfig



410
411
412
413
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 410

class StreamingDetectIntentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#output_audio_config_mask::Google::Protobuf::FieldMask



410
411
412
413
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 410

class StreamingDetectIntentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#query_input::Google::Cloud::Dialogflow::V2::QueryInput



410
411
412
413
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 410

class StreamingDetectIntentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#query_params::Google::Cloud::Dialogflow::V2::QueryParameters



410
411
412
413
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 410

class StreamingDetectIntentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#session::String



410
411
412
413
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 410

class StreamingDetectIntentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#single_utterance::Boolean



410
411
412
413
# File 'proto_docs/google/cloud/dialogflow/v2/session.rb', line 410

class StreamingDetectIntentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end