Class: Google::Cloud::Dialogflow::V2::ToolsetTool

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/toolset.rb

Overview

A tool that is created from a toolset.

Instance Attribute Summary collapse

Instance Attribute Details

#confirmation_requirement::Google::Cloud::Dialogflow::V2::Tool::ConfirmationRequirement

Returns Optional. Indicates whether the tool requires human confirmation.

Returns:



37
38
39
40
# File 'proto_docs/google/cloud/dialogflow/v2/toolset.rb', line 37

class ToolsetTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#operation_id::String

Returns Optional. The operationId field of the OpenAPI endpoint. The operationId must be present in the toolset's definition.

Returns:

  • (::String)

    Optional. The operationId field of the OpenAPI endpoint. The operationId must be present in the toolset's definition.



37
38
39
40
# File 'proto_docs/google/cloud/dialogflow/v2/toolset.rb', line 37

class ToolsetTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#toolset::String

Returns Required. The name of the toolset to retrieve the schema for. Format: projects/{project}/locations/{location}/apps/{app}/toolsets/{toolset}.

Returns:

  • (::String)

    Required. The name of the toolset to retrieve the schema for. Format: projects/{project}/locations/{location}/apps/{app}/toolsets/{toolset}



37
38
39
40
# File 'proto_docs/google/cloud/dialogflow/v2/toolset.rb', line 37

class ToolsetTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end