Class: Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/generator.rb
Overview
Suggestion for coaching agents.
Defined Under Namespace
Classes: AgentActionSuggestion, DuplicateCheckResult, SampleResponse, Sources
Instance Attribute Summary collapse
-
#agent_action_suggestions ⇒ ::Array<::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::AgentActionSuggestion>
Optional.
-
#applicable_instructions ⇒ ::Array<::Google::Cloud::Dialogflow::V2::AgentCoachingInstruction>
Optional.
-
#sample_responses ⇒ ::Array<::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::SampleResponse>
Optional.
Instance Attribute Details
#agent_action_suggestions ⇒ ::Array<::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::AgentActionSuggestion>
Returns Optional. Suggested actions for the agent to take.
448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 |
# File 'proto_docs/google/cloud/dialogflow/v2/generator.rb', line 448 class AgentCoachingSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Sources for the suggestion. # @!attribute [r] instruction_indexes # @return [::Array<::Integer>] # Output only. Source instruction indexes for the suggestion. This is the # index of the applicable_instructions field. class Sources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Duplication check for the suggestion. # @!attribute [r] duplicate_suggestions # @return [::Array<::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult::DuplicateSuggestion>] # Output only. The duplicate suggestions. class DuplicateCheckResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The duplicate suggestion details. # Keeping answer_record and sources together as they are identifiers for # duplicate suggestions. # @!attribute [r] answer_record # @return [::String] # Output only. The answer record id of the past duplicate suggestion. # @!attribute [r] sources # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::Sources] # Output only. Sources for the suggestion. # @!attribute [r] suggestion_index # @return [::Integer] # Output only. The index of the duplicate suggestion in the past # suggestion list. # @!attribute [r] similarity_score # @return [::Float] # Output only. The similarity score of between the past and current # suggestion. class DuplicateSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Actions suggested for the agent. This is based on applicable instructions. # @!attribute [rw] agent_action # @return [::String] # Optional. The suggested action for the agent. # @!attribute [r] sources # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::Sources] # Output only. Sources for the agent action suggestion. # @!attribute [r] duplicate_check_result # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult] # Output only. Duplicate check result for the agent action suggestion. class AgentActionSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Sample response that the agent can use. This could be based on applicable # instructions and ingested data from other systems. # @!attribute [rw] response_text # @return [::String] # Optional. Sample response for Agent in text. # @!attribute [r] sources # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::Sources] # Output only. Sources for the Sample Response. # @!attribute [r] duplicate_check_result # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult] # Output only. Duplicate check result for the sample response. class SampleResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#applicable_instructions ⇒ ::Array<::Google::Cloud::Dialogflow::V2::AgentCoachingInstruction>
Returns Optional. Instructions applicable based on the current context.
448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 |
# File 'proto_docs/google/cloud/dialogflow/v2/generator.rb', line 448 class AgentCoachingSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Sources for the suggestion. # @!attribute [r] instruction_indexes # @return [::Array<::Integer>] # Output only. Source instruction indexes for the suggestion. This is the # index of the applicable_instructions field. class Sources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Duplication check for the suggestion. # @!attribute [r] duplicate_suggestions # @return [::Array<::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult::DuplicateSuggestion>] # Output only. The duplicate suggestions. class DuplicateCheckResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The duplicate suggestion details. # Keeping answer_record and sources together as they are identifiers for # duplicate suggestions. # @!attribute [r] answer_record # @return [::String] # Output only. The answer record id of the past duplicate suggestion. # @!attribute [r] sources # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::Sources] # Output only. Sources for the suggestion. # @!attribute [r] suggestion_index # @return [::Integer] # Output only. The index of the duplicate suggestion in the past # suggestion list. # @!attribute [r] similarity_score # @return [::Float] # Output only. The similarity score of between the past and current # suggestion. class DuplicateSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Actions suggested for the agent. This is based on applicable instructions. # @!attribute [rw] agent_action # @return [::String] # Optional. The suggested action for the agent. # @!attribute [r] sources # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::Sources] # Output only. Sources for the agent action suggestion. # @!attribute [r] duplicate_check_result # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult] # Output only. Duplicate check result for the agent action suggestion. class AgentActionSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Sample response that the agent can use. This could be based on applicable # instructions and ingested data from other systems. # @!attribute [rw] response_text # @return [::String] # Optional. Sample response for Agent in text. # @!attribute [r] sources # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::Sources] # Output only. Sources for the Sample Response. # @!attribute [r] duplicate_check_result # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult] # Output only. Duplicate check result for the sample response. class SampleResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#sample_responses ⇒ ::Array<::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::SampleResponse>
Returns Optional. Sample response for the Agent.
448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 |
# File 'proto_docs/google/cloud/dialogflow/v2/generator.rb', line 448 class AgentCoachingSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Sources for the suggestion. # @!attribute [r] instruction_indexes # @return [::Array<::Integer>] # Output only. Source instruction indexes for the suggestion. This is the # index of the applicable_instructions field. class Sources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Duplication check for the suggestion. # @!attribute [r] duplicate_suggestions # @return [::Array<::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult::DuplicateSuggestion>] # Output only. The duplicate suggestions. class DuplicateCheckResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The duplicate suggestion details. # Keeping answer_record and sources together as they are identifiers for # duplicate suggestions. # @!attribute [r] answer_record # @return [::String] # Output only. The answer record id of the past duplicate suggestion. # @!attribute [r] sources # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::Sources] # Output only. Sources for the suggestion. # @!attribute [r] suggestion_index # @return [::Integer] # Output only. The index of the duplicate suggestion in the past # suggestion list. # @!attribute [r] similarity_score # @return [::Float] # Output only. The similarity score of between the past and current # suggestion. class DuplicateSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Actions suggested for the agent. This is based on applicable instructions. # @!attribute [rw] agent_action # @return [::String] # Optional. The suggested action for the agent. # @!attribute [r] sources # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::Sources] # Output only. Sources for the agent action suggestion. # @!attribute [r] duplicate_check_result # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult] # Output only. Duplicate check result for the agent action suggestion. class AgentActionSuggestion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Sample response that the agent can use. This could be based on applicable # instructions and ingested data from other systems. # @!attribute [rw] response_text # @return [::String] # Optional. Sample response for Agent in text. # @!attribute [r] sources # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::Sources] # Output only. Sources for the Sample Response. # @!attribute [r] duplicate_check_result # @return [::Google::Cloud::Dialogflow::V2::AgentCoachingSuggestion::DuplicateCheckResult] # Output only. Duplicate check result for the sample response. class SampleResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |