Class: Google::Cloud::Dialogflow::V2::CustomPronunciationParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/audio_config.rb

Overview

Pronunciation customization for a phrase.

Defined Under Namespace

Modules: PhoneticEncoding

Instance Attribute Summary collapse

Instance Attribute Details

#phonetic_encoding::Google::Cloud::Dialogflow::V2::CustomPronunciationParams::PhoneticEncoding

Returns The phonetic encoding of the phrase.

Returns:



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'proto_docs/google/cloud/dialogflow/v2/audio_config.rb', line 248

class CustomPronunciationParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The phonetic encoding of the phrase.
  module PhoneticEncoding
    # Not specified.
    PHONETIC_ENCODING_UNSPECIFIED = 0

    # IPA, such as apple -> ˈæpəl.
    # https://en.wikipedia.org/wiki/International_Phonetic_Alphabet
    PHONETIC_ENCODING_IPA = 1

    # X-SAMPA, such as apple -> "{p@l".
    # https://en.wikipedia.org/wiki/X-SAMPA
    PHONETIC_ENCODING_X_SAMPA = 2
  end
end

#phrase::String

Returns The phrase to which the customization is applied. The phrase can be multiple words, such as proper nouns, but shouldn't span the length of the sentence.

Returns:

  • (::String)

    The phrase to which the customization is applied. The phrase can be multiple words, such as proper nouns, but shouldn't span the length of the sentence.



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'proto_docs/google/cloud/dialogflow/v2/audio_config.rb', line 248

class CustomPronunciationParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The phonetic encoding of the phrase.
  module PhoneticEncoding
    # Not specified.
    PHONETIC_ENCODING_UNSPECIFIED = 0

    # IPA, such as apple -> ˈæpəl.
    # https://en.wikipedia.org/wiki/International_Phonetic_Alphabet
    PHONETIC_ENCODING_IPA = 1

    # X-SAMPA, such as apple -> "{p@l".
    # https://en.wikipedia.org/wiki/X-SAMPA
    PHONETIC_ENCODING_X_SAMPA = 2
  end
end

#pronunciation::String

Returns The pronunciation of the phrase. This must be in the phonetic encoding specified above.

Returns:

  • (::String)

    The pronunciation of the phrase. This must be in the phonetic encoding specified above.



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'proto_docs/google/cloud/dialogflow/v2/audio_config.rb', line 248

class CustomPronunciationParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The phonetic encoding of the phrase.
  module PhoneticEncoding
    # Not specified.
    PHONETIC_ENCODING_UNSPECIFIED = 0

    # IPA, such as apple -> ˈæpəl.
    # https://en.wikipedia.org/wiki/International_Phonetic_Alphabet
    PHONETIC_ENCODING_IPA = 1

    # X-SAMPA, such as apple -> "{p@l".
    # https://en.wikipedia.org/wiki/X-SAMPA
    PHONETIC_ENCODING_X_SAMPA = 2
  end
end