Class: Google::Cloud::Dialogflow::V2::GenerateStatelessSummaryResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/conversation.rb

Overview

The response message for Conversations.GenerateStatelessSummary.

Defined Under Namespace

Classes: Summary

Instance Attribute Summary collapse

Instance Attribute Details

#context_size::Integer

Returns Number of messages prior to and including latest_message used to compile the suggestion. It may be smaller than the GenerateStatelessSummaryRequest.max_context_size field in the request if there weren't that many messages in the conversation.

Returns:



639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 639

class GenerateStatelessSummaryResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Generated summary for a conversation.
  # @!attribute [rw] text
  #   @return [::String]
  #     The summary content that is concatenated into one string.
  # @!attribute [rw] text_sections
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The summary content that is divided into sections. The key is the
  #     section's name and the value is the section's content. There is no
  #     specific format for the key or value.
  # @!attribute [rw] baseline_model_version
  #   @return [::String]
  #     The baseline model version used to generate this summary. It is empty if
  #     a baseline model was not used to generate this summary.
  class Summary
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TextSectionsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#latest_message::String

Returns The name of the latest conversation message used as context for compiling suggestion. The format is specific to the user and the names of the messages provided.

Returns:

  • (::String)

    The name of the latest conversation message used as context for compiling suggestion. The format is specific to the user and the names of the messages provided.



639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 639

class GenerateStatelessSummaryResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Generated summary for a conversation.
  # @!attribute [rw] text
  #   @return [::String]
  #     The summary content that is concatenated into one string.
  # @!attribute [rw] text_sections
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The summary content that is divided into sections. The key is the
  #     section's name and the value is the section's content. There is no
  #     specific format for the key or value.
  # @!attribute [rw] baseline_model_version
  #   @return [::String]
  #     The baseline model version used to generate this summary. It is empty if
  #     a baseline model was not used to generate this summary.
  class Summary
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TextSectionsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#summary::Google::Cloud::Dialogflow::V2::GenerateStatelessSummaryResponse::Summary

Returns Generated summary.



639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 639

class GenerateStatelessSummaryResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Generated summary for a conversation.
  # @!attribute [rw] text
  #   @return [::String]
  #     The summary content that is concatenated into one string.
  # @!attribute [rw] text_sections
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     The summary content that is divided into sections. The key is the
  #     section's name and the value is the section's content. There is no
  #     specific format for the key or value.
  # @!attribute [rw] baseline_model_version
  #   @return [::String]
  #     The baseline model version used to generate this summary. It is empty if
  #     a baseline model was not used to generate this summary.
  class Summary
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class TextSectionsEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end