Class: Google::Cloud::Dialogflow::V2::GenerateStatelessSummaryResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::GenerateStatelessSummaryResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/conversation.rb
Overview
The response message for Conversations.GenerateStatelessSummary.
Defined Under Namespace
Classes: Summary
Instance Attribute Summary collapse
-
#context_size ⇒ ::Integer
Number of messages prior to and including latest_message used to compile the suggestion.
-
#latest_message ⇒ ::String
The name of the latest conversation message used as context for compiling suggestion.
-
#summary ⇒ ::Google::Cloud::Dialogflow::V2::GenerateStatelessSummaryResponse::Summary
Generated summary.
Instance Attribute Details
#context_size ⇒ ::Integer
572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 572 class GenerateStatelessSummaryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Generated summary for a conversation. # @!attribute [rw] text # @return [::String] # The summary content that is concatenated into one string. # @!attribute [rw] text_sections # @return [::Google::Protobuf::Map{::String => ::String}] # The summary content that is divided into sections. The key is the # section's name and the value is the section's content. There is no # specific format for the key or value. # @!attribute [rw] baseline_model_version # @return [::String] # The baseline model version used to generate this summary. It is empty if # a baseline model was not used to generate this summary. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TextSectionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#latest_message ⇒ ::String
572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 572 class GenerateStatelessSummaryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Generated summary for a conversation. # @!attribute [rw] text # @return [::String] # The summary content that is concatenated into one string. # @!attribute [rw] text_sections # @return [::Google::Protobuf::Map{::String => ::String}] # The summary content that is divided into sections. The key is the # section's name and the value is the section's content. There is no # specific format for the key or value. # @!attribute [rw] baseline_model_version # @return [::String] # The baseline model version used to generate this summary. It is empty if # a baseline model was not used to generate this summary. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TextSectionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#summary ⇒ ::Google::Cloud::Dialogflow::V2::GenerateStatelessSummaryResponse::Summary
572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 572 class GenerateStatelessSummaryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Generated summary for a conversation. # @!attribute [rw] text # @return [::String] # The summary content that is concatenated into one string. # @!attribute [rw] text_sections # @return [::Google::Protobuf::Map{::String => ::String}] # The summary content that is divided into sections. The key is the # section's name and the value is the section's content. There is no # specific format for the key or value. # @!attribute [rw] baseline_model_version # @return [::String] # The baseline model version used to generate this summary. It is empty if # a baseline model was not used to generate this summary. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TextSectionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |