Class: Google::Cloud::Dialogflow::V2::IngestedContextReferenceDebugInfo::IngestedParameterDebugInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::IngestedContextReferenceDebugInfo::IngestedParameterDebugInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/participant.rb
Overview
Debug information related to ingested parameters from context reference.
Defined Under Namespace
Modules: IngestionStatus
Instance Attribute Summary collapse
-
#ingestion_status ⇒ ::Google::Cloud::Dialogflow::V2::IngestedContextReferenceDebugInfo::IngestedParameterDebugInfo::IngestionStatus
The ingestion status for this specific parameter.
-
#parameter ⇒ ::String
The name of the parameter in the context reference.
Instance Attribute Details
#ingestion_status ⇒ ::Google::Cloud::Dialogflow::V2::IngestedContextReferenceDebugInfo::IngestedParameterDebugInfo::IngestionStatus
Returns The ingestion status for this specific parameter.
1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1267 class IngestedParameterDebugInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum representing the various states of parameter ingestion. module IngestionStatus # Default value, indicates that the ingestion status is not specified. INGESTION_STATUS_UNSPECIFIED = 0 # Indicates that the parameter was successfully ingested. INGESTION_STATUS_SUCCEEDED = 1 # Indicates that the parameter was not available for ingestion. INGESTION_STATUS_CONTEXT_NOT_AVAILABLE = 2 # Indicates that there was a failure parsing the parameter content. INGESTION_STATUS_PARSE_FAILED = 3 # Indicates that the context reference had an unexpected number of # content entries as Context reference should only have one entry. INGESTION_STATUS_INVALID_ENTRY = 4 # Indicates that the context reference content was not in the expected # format (e.g., JSON). INGESTION_STATUS_INVALID_FORMAT = 5 # Indicates that the context reference language does not match the # conversation language. INGESTION_STATUS_LANGUAGE_MISMATCH = 6 end end |
#parameter ⇒ ::String
Returns The name of the parameter in the context reference.
1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1267 class IngestedParameterDebugInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum representing the various states of parameter ingestion. module IngestionStatus # Default value, indicates that the ingestion status is not specified. INGESTION_STATUS_UNSPECIFIED = 0 # Indicates that the parameter was successfully ingested. INGESTION_STATUS_SUCCEEDED = 1 # Indicates that the parameter was not available for ingestion. INGESTION_STATUS_CONTEXT_NOT_AVAILABLE = 2 # Indicates that there was a failure parsing the parameter content. INGESTION_STATUS_PARSE_FAILED = 3 # Indicates that the context reference had an unexpected number of # content entries as Context reference should only have one entry. INGESTION_STATUS_INVALID_ENTRY = 4 # Indicates that the context reference content was not in the expected # format (e.g., JSON). INGESTION_STATUS_INVALID_FORMAT = 5 # Indicates that the context reference language does not match the # conversation language. INGESTION_STATUS_LANGUAGE_MISMATCH = 6 end end |