Class: Google::Cloud::Dialogflow::V2::Intent::Message::BasicCard
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::Intent::Message::BasicCard
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/intent.rb
Overview
The basic card message. Useful for displaying information.
Defined Under Namespace
Classes: Button
Instance Attribute Summary collapse
-
#buttons ⇒ ::Array<::Google::Cloud::Dialogflow::V2::Intent::Message::BasicCard::Button>
Optional.
-
#formatted_text ⇒ ::String
Required, unless image is present.
-
#image ⇒ ::Google::Cloud::Dialogflow::V2::Intent::Message::Image
Optional.
-
#subtitle ⇒ ::String
Optional.
-
#title ⇒ ::String
Optional.
Instance Attribute Details
#buttons ⇒ ::Array<::Google::Cloud::Dialogflow::V2::Intent::Message::BasicCard::Button>
465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'proto_docs/google/cloud/dialogflow/v2/intent.rb', line 465 class BasicCard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The button object that appears at the bottom of a card. # @!attribute [rw] title # @return [::String] # Required. The title of the button. # @!attribute [rw] open_uri_action # @return [::Google::Cloud::Dialogflow::V2::Intent::Message::BasicCard::Button::OpenUriAction] # Required. Action to take when a user taps on the button. class Button include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Opens the given URI. # @!attribute [rw] uri # @return [::String] # Required. The HTTP or HTTPS scheme URI. class OpenUriAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#formatted_text ⇒ ::String
465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'proto_docs/google/cloud/dialogflow/v2/intent.rb', line 465 class BasicCard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The button object that appears at the bottom of a card. # @!attribute [rw] title # @return [::String] # Required. The title of the button. # @!attribute [rw] open_uri_action # @return [::Google::Cloud::Dialogflow::V2::Intent::Message::BasicCard::Button::OpenUriAction] # Required. Action to take when a user taps on the button. class Button include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Opens the given URI. # @!attribute [rw] uri # @return [::String] # Required. The HTTP or HTTPS scheme URI. class OpenUriAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#image ⇒ ::Google::Cloud::Dialogflow::V2::Intent::Message::Image
465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'proto_docs/google/cloud/dialogflow/v2/intent.rb', line 465 class BasicCard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The button object that appears at the bottom of a card. # @!attribute [rw] title # @return [::String] # Required. The title of the button. # @!attribute [rw] open_uri_action # @return [::Google::Cloud::Dialogflow::V2::Intent::Message::BasicCard::Button::OpenUriAction] # Required. Action to take when a user taps on the button. class Button include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Opens the given URI. # @!attribute [rw] uri # @return [::String] # Required. The HTTP or HTTPS scheme URI. class OpenUriAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#subtitle ⇒ ::String
465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'proto_docs/google/cloud/dialogflow/v2/intent.rb', line 465 class BasicCard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The button object that appears at the bottom of a card. # @!attribute [rw] title # @return [::String] # Required. The title of the button. # @!attribute [rw] open_uri_action # @return [::Google::Cloud::Dialogflow::V2::Intent::Message::BasicCard::Button::OpenUriAction] # Required. Action to take when a user taps on the button. class Button include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Opens the given URI. # @!attribute [rw] uri # @return [::String] # Required. The HTTP or HTTPS scheme URI. class OpenUriAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#title ⇒ ::String
465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'proto_docs/google/cloud/dialogflow/v2/intent.rb', line 465 class BasicCard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The button object that appears at the bottom of a card. # @!attribute [rw] title # @return [::String] # Required. The title of the button. # @!attribute [rw] open_uri_action # @return [::Google::Cloud::Dialogflow::V2::Intent::Message::BasicCard::Button::OpenUriAction] # Required. Action to take when a user taps on the button. class Button include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Opens the given URI. # @!attribute [rw] uri # @return [::String] # Required. The HTTP or HTTPS scheme URI. class OpenUriAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |