Class: Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/participant.rb

Overview

Represents a Knowledge Assist answer.

Defined Under Namespace

Classes: KnowledgeAnswer, SuggestedQuery

Instance Attribute Summary collapse

Instance Attribute Details

#answer_record::String

Returns The name of the answer record. Format: projects/<Project ID>/locations/<location ID>/answer Records/<Answer Record ID>.

Returns:

  • (::String)

    The name of the answer record. Format: projects/<Project ID>/locations/<location ID>/answer Records/<Answer Record ID>.



1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1491

class KnowledgeAssistAnswer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a suggested query.
  # @!attribute [rw] query_text
  #   @return [::String]
  #     Suggested query text.
  class SuggestedQuery
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents an answer from Knowledge. Currently supports FAQ and Generative
  # answers.
  # @!attribute [rw] answer_text
  #   @return [::String]
  #     The piece of text from the `source` that answers this suggested query.
  # @!attribute [rw] faq_source
  #   @return [::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::FaqSource]
  #     Populated if the prediction came from FAQ.
  #
  #     Note: The following fields are mutually exclusive: `faq_source`, `generative_source`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] generative_source
  #   @return [::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource]
  #     Populated if the prediction was Generative.
  #
  #     Note: The following fields are mutually exclusive: `generative_source`, `faq_source`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class KnowledgeAnswer
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Details about source of FAQ answer.
    # @!attribute [rw] question
    #   @return [::String]
    #     The corresponding FAQ question.
    class FaqSource
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Details about source of Generative answer.
    # @!attribute [rw] snippets
    #   @return [::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource::Snippet>]
    #     All snippets used for this Generative Prediction, with their source URI
    #     and data.
    class GenerativeSource
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # Snippet Source for a Generative Prediction.
      # @!attribute [rw] uri
      #   @return [::String]
      #     URI the data is sourced from.
      # @!attribute [rw] text
      #   @return [::String]
      #     Text taken from that URI.
      # @!attribute [rw] title
      #   @return [::String]
      #     Title of the document.
      # @!attribute [rw] metadata
      #   @return [::Google::Protobuf::Struct]
      #     Metadata of the document.
      class Snippet
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end
    end
  end
end

#knowledge_assist_debug_info::Google::Cloud::Dialogflow::V2::KnowledgeAssistDebugInfo

Returns Debug information related to Knowledge Assist feature.

Returns:



1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1491

class KnowledgeAssistAnswer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a suggested query.
  # @!attribute [rw] query_text
  #   @return [::String]
  #     Suggested query text.
  class SuggestedQuery
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents an answer from Knowledge. Currently supports FAQ and Generative
  # answers.
  # @!attribute [rw] answer_text
  #   @return [::String]
  #     The piece of text from the `source` that answers this suggested query.
  # @!attribute [rw] faq_source
  #   @return [::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::FaqSource]
  #     Populated if the prediction came from FAQ.
  #
  #     Note: The following fields are mutually exclusive: `faq_source`, `generative_source`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] generative_source
  #   @return [::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource]
  #     Populated if the prediction was Generative.
  #
  #     Note: The following fields are mutually exclusive: `generative_source`, `faq_source`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class KnowledgeAnswer
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Details about source of FAQ answer.
    # @!attribute [rw] question
    #   @return [::String]
    #     The corresponding FAQ question.
    class FaqSource
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Details about source of Generative answer.
    # @!attribute [rw] snippets
    #   @return [::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource::Snippet>]
    #     All snippets used for this Generative Prediction, with their source URI
    #     and data.
    class GenerativeSource
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # Snippet Source for a Generative Prediction.
      # @!attribute [rw] uri
      #   @return [::String]
      #     URI the data is sourced from.
      # @!attribute [rw] text
      #   @return [::String]
      #     Text taken from that URI.
      # @!attribute [rw] title
      #   @return [::String]
      #     Title of the document.
      # @!attribute [rw] metadata
      #   @return [::Google::Protobuf::Struct]
      #     Metadata of the document.
      class Snippet
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end
    end
  end
end

#suggested_query::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::SuggestedQuery

Returns The query suggested based on the context. Suggestion is made only if it is different from the previous suggestion.

Returns:



1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1491

class KnowledgeAssistAnswer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a suggested query.
  # @!attribute [rw] query_text
  #   @return [::String]
  #     Suggested query text.
  class SuggestedQuery
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents an answer from Knowledge. Currently supports FAQ and Generative
  # answers.
  # @!attribute [rw] answer_text
  #   @return [::String]
  #     The piece of text from the `source` that answers this suggested query.
  # @!attribute [rw] faq_source
  #   @return [::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::FaqSource]
  #     Populated if the prediction came from FAQ.
  #
  #     Note: The following fields are mutually exclusive: `faq_source`, `generative_source`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] generative_source
  #   @return [::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource]
  #     Populated if the prediction was Generative.
  #
  #     Note: The following fields are mutually exclusive: `generative_source`, `faq_source`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class KnowledgeAnswer
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Details about source of FAQ answer.
    # @!attribute [rw] question
    #   @return [::String]
    #     The corresponding FAQ question.
    class FaqSource
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Details about source of Generative answer.
    # @!attribute [rw] snippets
    #   @return [::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource::Snippet>]
    #     All snippets used for this Generative Prediction, with their source URI
    #     and data.
    class GenerativeSource
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # Snippet Source for a Generative Prediction.
      # @!attribute [rw] uri
      #   @return [::String]
      #     URI the data is sourced from.
      # @!attribute [rw] text
      #   @return [::String]
      #     Text taken from that URI.
      # @!attribute [rw] title
      #   @return [::String]
      #     Title of the document.
      # @!attribute [rw] metadata
      #   @return [::Google::Protobuf::Struct]
      #     Metadata of the document.
      class Snippet
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end
    end
  end
end

#suggested_query_answer::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer

Returns The answer generated for the suggested query. Whether or not an answer is generated depends on how confident we are about the generated query.

Returns:



1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1491

class KnowledgeAssistAnswer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a suggested query.
  # @!attribute [rw] query_text
  #   @return [::String]
  #     Suggested query text.
  class SuggestedQuery
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents an answer from Knowledge. Currently supports FAQ and Generative
  # answers.
  # @!attribute [rw] answer_text
  #   @return [::String]
  #     The piece of text from the `source` that answers this suggested query.
  # @!attribute [rw] faq_source
  #   @return [::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::FaqSource]
  #     Populated if the prediction came from FAQ.
  #
  #     Note: The following fields are mutually exclusive: `faq_source`, `generative_source`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] generative_source
  #   @return [::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource]
  #     Populated if the prediction was Generative.
  #
  #     Note: The following fields are mutually exclusive: `generative_source`, `faq_source`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class KnowledgeAnswer
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Details about source of FAQ answer.
    # @!attribute [rw] question
    #   @return [::String]
    #     The corresponding FAQ question.
    class FaqSource
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Details about source of Generative answer.
    # @!attribute [rw] snippets
    #   @return [::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource::Snippet>]
    #     All snippets used for this Generative Prediction, with their source URI
    #     and data.
    class GenerativeSource
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # Snippet Source for a Generative Prediction.
      # @!attribute [rw] uri
      #   @return [::String]
      #     URI the data is sourced from.
      # @!attribute [rw] text
      #   @return [::String]
      #     Text taken from that URI.
      # @!attribute [rw] title
      #   @return [::String]
      #     Title of the document.
      # @!attribute [rw] metadata
      #   @return [::Google::Protobuf::Struct]
      #     Metadata of the document.
      class Snippet
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end
    end
  end
end