Class: Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/participant.rb

Overview

Represents an answer from Knowledge. Currently supports FAQ and Generative answers.

Defined Under Namespace

Classes: FaqSource, GenerativeSource

Instance Attribute Summary collapse

Instance Attribute Details

#answer_text::String

Returns The piece of text from the source that answers this suggested query.

Returns:

  • (::String)

    The piece of text from the source that answers this suggested query.



1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1519

class KnowledgeAnswer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Details about source of FAQ answer.
  # @!attribute [rw] question
  #   @return [::String]
  #     The corresponding FAQ question.
  class FaqSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Details about source of Generative answer.
  # @!attribute [rw] snippets
  #   @return [::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource::Snippet>]
  #     All snippets used for this Generative Prediction, with their source URI
  #     and data.
  class GenerativeSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Snippet Source for a Generative Prediction.
    # @!attribute [rw] uri
    #   @return [::String]
    #     URI the data is sourced from.
    # @!attribute [rw] text
    #   @return [::String]
    #     Text taken from that URI.
    # @!attribute [rw] title
    #   @return [::String]
    #     Title of the document.
    # @!attribute [rw] metadata
    #   @return [::Google::Protobuf::Struct]
    #     Metadata of the document.
    class Snippet
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#faq_source::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::FaqSource

Returns Populated if the prediction came from FAQ.

Note: The following fields are mutually exclusive: faq_source, generative_source. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1519

class KnowledgeAnswer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Details about source of FAQ answer.
  # @!attribute [rw] question
  #   @return [::String]
  #     The corresponding FAQ question.
  class FaqSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Details about source of Generative answer.
  # @!attribute [rw] snippets
  #   @return [::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource::Snippet>]
  #     All snippets used for this Generative Prediction, with their source URI
  #     and data.
  class GenerativeSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Snippet Source for a Generative Prediction.
    # @!attribute [rw] uri
    #   @return [::String]
    #     URI the data is sourced from.
    # @!attribute [rw] text
    #   @return [::String]
    #     Text taken from that URI.
    # @!attribute [rw] title
    #   @return [::String]
    #     Title of the document.
    # @!attribute [rw] metadata
    #   @return [::Google::Protobuf::Struct]
    #     Metadata of the document.
    class Snippet
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#generative_source::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource

Returns Populated if the prediction was Generative.

Note: The following fields are mutually exclusive: generative_source, faq_source. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1519

class KnowledgeAnswer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Details about source of FAQ answer.
  # @!attribute [rw] question
  #   @return [::String]
  #     The corresponding FAQ question.
  class FaqSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Details about source of Generative answer.
  # @!attribute [rw] snippets
  #   @return [::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource::Snippet>]
  #     All snippets used for this Generative Prediction, with their source URI
  #     and data.
  class GenerativeSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Snippet Source for a Generative Prediction.
    # @!attribute [rw] uri
    #   @return [::String]
    #     URI the data is sourced from.
    # @!attribute [rw] text
    #   @return [::String]
    #     Text taken from that URI.
    # @!attribute [rw] title
    #   @return [::String]
    #     Title of the document.
    # @!attribute [rw] metadata
    #   @return [::Google::Protobuf::Struct]
    #     Metadata of the document.
    class Snippet
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end