Class: Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/participant.rb
Overview
Details about source of Generative answer.
Defined Under Namespace
Classes: Snippet
Instance Attribute Summary collapse
-
#snippets ⇒ ::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource::Snippet>
All snippets used for this Generative Prediction, with their source URI and data.
Instance Attribute Details
#snippets ⇒ ::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource::Snippet>
Returns All snippets used for this Generative Prediction, with their source URI and data.
1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1616 class GenerativeSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Snippet Source for a Generative Prediction. # @!attribute [rw] uri # @return [::String] # URI the data is sourced from. # @!attribute [rw] text # @return [::String] # Text taken from that URI. # @!attribute [rw] title # @return [::String] # Title of the document. # @!attribute [rw] metadata # @return [::Google::Protobuf::Struct] # Metadata of the document. class Snippet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |