Class: Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/participant.rb
Overview
Details about source of Generative answer.
Defined Under Namespace
Classes: Snippet
Instance Attribute Summary collapse
-
#snippets ⇒ ::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource::Snippet>
All snippets used for this Generative Prediction, with their source URI and data.
Instance Attribute Details
#snippets ⇒ ::Array<::Google::Cloud::Dialogflow::V2::KnowledgeAssistAnswer::KnowledgeAnswer::GenerativeSource::Snippet>
Returns All snippets used for this Generative Prediction, with their source URI and data.
1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1537 class GenerativeSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Snippet Source for a Generative Prediction. # @!attribute [rw] uri # @return [::String] # URI the data is sourced from. # @!attribute [rw] text # @return [::String] # Text taken from that URI. # @!attribute [rw] title # @return [::String] # Title of the document. # @!attribute [rw] metadata # @return [::Google::Protobuf::Struct] # Metadata of the document. class Snippet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |