Class: Google::Cloud::Dialogflow::V2::KnowledgeAssistDebugInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/participant.rb

Overview

Debug information related to Knowledge Assist feature.

Defined Under Namespace

Modules: QueryCategorizationFailureReason, QueryGenerationFailureReason Classes: KnowledgeAssistBehavior

Instance Attribute Summary collapse

Instance Attribute Details

#datastore_response_reason::Google::Cloud::Dialogflow::V2::DatastoreResponseReason

Returns Response reason from datastore which indicates data serving status or answer quality degradation.

Returns:



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1347

class KnowledgeAssistDebugInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configured behaviors for Knowedge Assist.
  # @!attribute [rw] answer_generation_rewriter_on
  #   @return [::Boolean]
  #     Whether data store agent rewriter was turned off for the request.
  # @!attribute [rw] end_user_metadata_included
  #   @return [::Boolean]
  #     Whether end_user_metadata is included in the data store agent call.
  # @!attribute [rw] return_query_only
  #   @return [::Boolean]
  #     Whether customers configured to return query only in the
  #     conversation profile.
  # @!attribute [rw] use_pubsub_delivery
  #   @return [::Boolean]
  #     Whether customers configured to use pubsub to deliver.
  # @!attribute [rw] disable_sync_delivery
  #   @return [::Boolean]
  #     Whether customers configured to disable the synchronous delivery of
  #     Knowedge Assist response.
  # @!attribute [rw] previous_queries_included
  #   @return [::Boolean]
  #     Whether previously suggested queries are included in the query generation
  #     process.
  # @!attribute [rw] use_translated_message
  #   @return [::Boolean]
  #     Translated message is included in query generation process.
  # @!attribute [rw] use_custom_safety_filter_level
  #   @return [::Boolean]
  #     Safety filter is adjusted by user.
  # @!attribute [rw] conversation_transcript_has_mixed_languages
  #   @return [::Boolean]
  #     Conversation transcript has mixed languages.
  # @!attribute [rw] query_generation_agent_language_mismatch
  #   @return [::Boolean]
  #     Whether the agent language from the translation generator mismatches the
  #     end-user language.
  # @!attribute [rw] query_generation_end_user_language_mismatch
  #   @return [::Boolean]
  #     Whether the end-user language from the translation generator mismatches
  #     the end-user language.
  # @!attribute [rw] third_party_connector_allowed
  #   @return [::Boolean]
  #     This field indicates whether third party connectors are enabled for the
  #     project
  # @!attribute [rw] multiple_queries_generated
  #   @return [::Boolean]
  #     Indicates that the query generation model generated multiple queries.
  # @!attribute [rw] query_contained_search_context
  #   @return [::Boolean]
  #     Indicates that the generated query contains search context.
  # @!attribute [rw] invalid_items_query_suggestion_skipped
  #   @return [::Boolean]
  #     Indicates that invalid items were skipped when parsing the LLM response.
  # @!attribute [rw] primary_query_redacted_and_replaced
  #   @return [::Boolean]
  #     True if the primary suggested query was redacted and replaced by an
  #     additional query.
  # @!attribute [rw] appended_search_context_count
  #   @return [::Integer]
  #     The number of search contexts appended to the query.
  class KnowledgeAssistBehavior
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Reason for query generation failure.
  module QueryGenerationFailureReason
    # Default value.
    QUERY_GENERATION_FAILURE_REASON_UNSPECIFIED = 0

    # Query generation is blocked due to out of quota.
    QUERY_GENERATION_OUT_OF_QUOTA = 1

    # Call to Knowedge Assist query generation model fails.
    QUERY_GENERATION_FAILED = 2

    # Query generation model decides that there is no new topic change or
    # there has been similar queries generated in the previous turns.
    QUERY_GENERATION_NO_QUERY_GENERATED = 3

    # Knowedge Assist generated query is blocked by RAI (Responsible AI).
    QUERY_GENERATION_RAI_FAILED = 4

    # Query generation is blocked by Knowledge Assist conversation profile
    # level / agent id level filtering.
    NOT_IN_ALLOWLIST = 5

    # The generated query is blocked due to redaction.
    QUERY_GENERATION_QUERY_REDACTED = 6

    # Query generation failed due to LLM response parse failure.
    QUERY_GENERATION_LLM_RESPONSE_PARSE_FAILED = 10

    # The conversation has no messages.
    QUERY_GENERATION_EMPTY_CONVERSATION = 11

    # The last message in the conversation is empty.
    QUERY_GENERATION_EMPTY_LAST_MESSAGE = 12

    # The trigger event condition is not met.
    # This occurs in the following scenarios:
    # 1. The trigger_event is CUSTOMER_MESSAGE or UNSPECIFIED, but the last
    #    message is not from the customer.
    # 2. The trigger_event is AGENT_MESSAGE, but the last message is not from
    #    the agent.
    QUERY_GENERATION_TRIGGERING_EVENT_CONDITION_NOT_MET = 13
  end

  # Reason for query categorization failure.
  module QueryCategorizationFailureReason
    # Default value.
    QUERY_CATEGORIZATION_FAILURE_REASON_UNSPECIFIED = 0

    # Vertex AI Search config supplied for query categorization is invalid.
    QUERY_CATEGORIZATION_INVALID_CONFIG = 1

    # Vertex AI Search result does not contain a query categorization result.
    QUERY_CATEGORIZATION_RESULT_NOT_FOUND = 2

    # Vertex AI Search call fails.
    QUERY_CATEGORIZATION_FAILED = 3
  end
end

#ingested_context_reference_debug_info::Google::Cloud::Dialogflow::V2::IngestedContextReferenceDebugInfo

Returns Information about parameters ingested for search knowledge.

Returns:



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1347

class KnowledgeAssistDebugInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configured behaviors for Knowedge Assist.
  # @!attribute [rw] answer_generation_rewriter_on
  #   @return [::Boolean]
  #     Whether data store agent rewriter was turned off for the request.
  # @!attribute [rw] end_user_metadata_included
  #   @return [::Boolean]
  #     Whether end_user_metadata is included in the data store agent call.
  # @!attribute [rw] return_query_only
  #   @return [::Boolean]
  #     Whether customers configured to return query only in the
  #     conversation profile.
  # @!attribute [rw] use_pubsub_delivery
  #   @return [::Boolean]
  #     Whether customers configured to use pubsub to deliver.
  # @!attribute [rw] disable_sync_delivery
  #   @return [::Boolean]
  #     Whether customers configured to disable the synchronous delivery of
  #     Knowedge Assist response.
  # @!attribute [rw] previous_queries_included
  #   @return [::Boolean]
  #     Whether previously suggested queries are included in the query generation
  #     process.
  # @!attribute [rw] use_translated_message
  #   @return [::Boolean]
  #     Translated message is included in query generation process.
  # @!attribute [rw] use_custom_safety_filter_level
  #   @return [::Boolean]
  #     Safety filter is adjusted by user.
  # @!attribute [rw] conversation_transcript_has_mixed_languages
  #   @return [::Boolean]
  #     Conversation transcript has mixed languages.
  # @!attribute [rw] query_generation_agent_language_mismatch
  #   @return [::Boolean]
  #     Whether the agent language from the translation generator mismatches the
  #     end-user language.
  # @!attribute [rw] query_generation_end_user_language_mismatch
  #   @return [::Boolean]
  #     Whether the end-user language from the translation generator mismatches
  #     the end-user language.
  # @!attribute [rw] third_party_connector_allowed
  #   @return [::Boolean]
  #     This field indicates whether third party connectors are enabled for the
  #     project
  # @!attribute [rw] multiple_queries_generated
  #   @return [::Boolean]
  #     Indicates that the query generation model generated multiple queries.
  # @!attribute [rw] query_contained_search_context
  #   @return [::Boolean]
  #     Indicates that the generated query contains search context.
  # @!attribute [rw] invalid_items_query_suggestion_skipped
  #   @return [::Boolean]
  #     Indicates that invalid items were skipped when parsing the LLM response.
  # @!attribute [rw] primary_query_redacted_and_replaced
  #   @return [::Boolean]
  #     True if the primary suggested query was redacted and replaced by an
  #     additional query.
  # @!attribute [rw] appended_search_context_count
  #   @return [::Integer]
  #     The number of search contexts appended to the query.
  class KnowledgeAssistBehavior
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Reason for query generation failure.
  module QueryGenerationFailureReason
    # Default value.
    QUERY_GENERATION_FAILURE_REASON_UNSPECIFIED = 0

    # Query generation is blocked due to out of quota.
    QUERY_GENERATION_OUT_OF_QUOTA = 1

    # Call to Knowedge Assist query generation model fails.
    QUERY_GENERATION_FAILED = 2

    # Query generation model decides that there is no new topic change or
    # there has been similar queries generated in the previous turns.
    QUERY_GENERATION_NO_QUERY_GENERATED = 3

    # Knowedge Assist generated query is blocked by RAI (Responsible AI).
    QUERY_GENERATION_RAI_FAILED = 4

    # Query generation is blocked by Knowledge Assist conversation profile
    # level / agent id level filtering.
    NOT_IN_ALLOWLIST = 5

    # The generated query is blocked due to redaction.
    QUERY_GENERATION_QUERY_REDACTED = 6

    # Query generation failed due to LLM response parse failure.
    QUERY_GENERATION_LLM_RESPONSE_PARSE_FAILED = 10

    # The conversation has no messages.
    QUERY_GENERATION_EMPTY_CONVERSATION = 11

    # The last message in the conversation is empty.
    QUERY_GENERATION_EMPTY_LAST_MESSAGE = 12

    # The trigger event condition is not met.
    # This occurs in the following scenarios:
    # 1. The trigger_event is CUSTOMER_MESSAGE or UNSPECIFIED, but the last
    #    message is not from the customer.
    # 2. The trigger_event is AGENT_MESSAGE, but the last message is not from
    #    the agent.
    QUERY_GENERATION_TRIGGERING_EVENT_CONDITION_NOT_MET = 13
  end

  # Reason for query categorization failure.
  module QueryCategorizationFailureReason
    # Default value.
    QUERY_CATEGORIZATION_FAILURE_REASON_UNSPECIFIED = 0

    # Vertex AI Search config supplied for query categorization is invalid.
    QUERY_CATEGORIZATION_INVALID_CONFIG = 1

    # Vertex AI Search result does not contain a query categorization result.
    QUERY_CATEGORIZATION_RESULT_NOT_FOUND = 2

    # Vertex AI Search call fails.
    QUERY_CATEGORIZATION_FAILED = 3
  end
end

#knowledge_assist_behavior::Google::Cloud::Dialogflow::V2::KnowledgeAssistDebugInfo::KnowledgeAssistBehavior

Returns Configured behaviors for Knowedge Assist.

Returns:



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1347

class KnowledgeAssistDebugInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configured behaviors for Knowedge Assist.
  # @!attribute [rw] answer_generation_rewriter_on
  #   @return [::Boolean]
  #     Whether data store agent rewriter was turned off for the request.
  # @!attribute [rw] end_user_metadata_included
  #   @return [::Boolean]
  #     Whether end_user_metadata is included in the data store agent call.
  # @!attribute [rw] return_query_only
  #   @return [::Boolean]
  #     Whether customers configured to return query only in the
  #     conversation profile.
  # @!attribute [rw] use_pubsub_delivery
  #   @return [::Boolean]
  #     Whether customers configured to use pubsub to deliver.
  # @!attribute [rw] disable_sync_delivery
  #   @return [::Boolean]
  #     Whether customers configured to disable the synchronous delivery of
  #     Knowedge Assist response.
  # @!attribute [rw] previous_queries_included
  #   @return [::Boolean]
  #     Whether previously suggested queries are included in the query generation
  #     process.
  # @!attribute [rw] use_translated_message
  #   @return [::Boolean]
  #     Translated message is included in query generation process.
  # @!attribute [rw] use_custom_safety_filter_level
  #   @return [::Boolean]
  #     Safety filter is adjusted by user.
  # @!attribute [rw] conversation_transcript_has_mixed_languages
  #   @return [::Boolean]
  #     Conversation transcript has mixed languages.
  # @!attribute [rw] query_generation_agent_language_mismatch
  #   @return [::Boolean]
  #     Whether the agent language from the translation generator mismatches the
  #     end-user language.
  # @!attribute [rw] query_generation_end_user_language_mismatch
  #   @return [::Boolean]
  #     Whether the end-user language from the translation generator mismatches
  #     the end-user language.
  # @!attribute [rw] third_party_connector_allowed
  #   @return [::Boolean]
  #     This field indicates whether third party connectors are enabled for the
  #     project
  # @!attribute [rw] multiple_queries_generated
  #   @return [::Boolean]
  #     Indicates that the query generation model generated multiple queries.
  # @!attribute [rw] query_contained_search_context
  #   @return [::Boolean]
  #     Indicates that the generated query contains search context.
  # @!attribute [rw] invalid_items_query_suggestion_skipped
  #   @return [::Boolean]
  #     Indicates that invalid items were skipped when parsing the LLM response.
  # @!attribute [rw] primary_query_redacted_and_replaced
  #   @return [::Boolean]
  #     True if the primary suggested query was redacted and replaced by an
  #     additional query.
  # @!attribute [rw] appended_search_context_count
  #   @return [::Integer]
  #     The number of search contexts appended to the query.
  class KnowledgeAssistBehavior
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Reason for query generation failure.
  module QueryGenerationFailureReason
    # Default value.
    QUERY_GENERATION_FAILURE_REASON_UNSPECIFIED = 0

    # Query generation is blocked due to out of quota.
    QUERY_GENERATION_OUT_OF_QUOTA = 1

    # Call to Knowedge Assist query generation model fails.
    QUERY_GENERATION_FAILED = 2

    # Query generation model decides that there is no new topic change or
    # there has been similar queries generated in the previous turns.
    QUERY_GENERATION_NO_QUERY_GENERATED = 3

    # Knowedge Assist generated query is blocked by RAI (Responsible AI).
    QUERY_GENERATION_RAI_FAILED = 4

    # Query generation is blocked by Knowledge Assist conversation profile
    # level / agent id level filtering.
    NOT_IN_ALLOWLIST = 5

    # The generated query is blocked due to redaction.
    QUERY_GENERATION_QUERY_REDACTED = 6

    # Query generation failed due to LLM response parse failure.
    QUERY_GENERATION_LLM_RESPONSE_PARSE_FAILED = 10

    # The conversation has no messages.
    QUERY_GENERATION_EMPTY_CONVERSATION = 11

    # The last message in the conversation is empty.
    QUERY_GENERATION_EMPTY_LAST_MESSAGE = 12

    # The trigger event condition is not met.
    # This occurs in the following scenarios:
    # 1. The trigger_event is CUSTOMER_MESSAGE or UNSPECIFIED, but the last
    #    message is not from the customer.
    # 2. The trigger_event is AGENT_MESSAGE, but the last message is not from
    #    the agent.
    QUERY_GENERATION_TRIGGERING_EVENT_CONDITION_NOT_MET = 13
  end

  # Reason for query categorization failure.
  module QueryCategorizationFailureReason
    # Default value.
    QUERY_CATEGORIZATION_FAILURE_REASON_UNSPECIFIED = 0

    # Vertex AI Search config supplied for query categorization is invalid.
    QUERY_CATEGORIZATION_INVALID_CONFIG = 1

    # Vertex AI Search result does not contain a query categorization result.
    QUERY_CATEGORIZATION_RESULT_NOT_FOUND = 2

    # Vertex AI Search call fails.
    QUERY_CATEGORIZATION_FAILED = 3
  end
end

#query_categorization_failure_reason::Google::Cloud::Dialogflow::V2::KnowledgeAssistDebugInfo::QueryCategorizationFailureReason

Returns Reason for query categorization.



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1347

class KnowledgeAssistDebugInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configured behaviors for Knowedge Assist.
  # @!attribute [rw] answer_generation_rewriter_on
  #   @return [::Boolean]
  #     Whether data store agent rewriter was turned off for the request.
  # @!attribute [rw] end_user_metadata_included
  #   @return [::Boolean]
  #     Whether end_user_metadata is included in the data store agent call.
  # @!attribute [rw] return_query_only
  #   @return [::Boolean]
  #     Whether customers configured to return query only in the
  #     conversation profile.
  # @!attribute [rw] use_pubsub_delivery
  #   @return [::Boolean]
  #     Whether customers configured to use pubsub to deliver.
  # @!attribute [rw] disable_sync_delivery
  #   @return [::Boolean]
  #     Whether customers configured to disable the synchronous delivery of
  #     Knowedge Assist response.
  # @!attribute [rw] previous_queries_included
  #   @return [::Boolean]
  #     Whether previously suggested queries are included in the query generation
  #     process.
  # @!attribute [rw] use_translated_message
  #   @return [::Boolean]
  #     Translated message is included in query generation process.
  # @!attribute [rw] use_custom_safety_filter_level
  #   @return [::Boolean]
  #     Safety filter is adjusted by user.
  # @!attribute [rw] conversation_transcript_has_mixed_languages
  #   @return [::Boolean]
  #     Conversation transcript has mixed languages.
  # @!attribute [rw] query_generation_agent_language_mismatch
  #   @return [::Boolean]
  #     Whether the agent language from the translation generator mismatches the
  #     end-user language.
  # @!attribute [rw] query_generation_end_user_language_mismatch
  #   @return [::Boolean]
  #     Whether the end-user language from the translation generator mismatches
  #     the end-user language.
  # @!attribute [rw] third_party_connector_allowed
  #   @return [::Boolean]
  #     This field indicates whether third party connectors are enabled for the
  #     project
  # @!attribute [rw] multiple_queries_generated
  #   @return [::Boolean]
  #     Indicates that the query generation model generated multiple queries.
  # @!attribute [rw] query_contained_search_context
  #   @return [::Boolean]
  #     Indicates that the generated query contains search context.
  # @!attribute [rw] invalid_items_query_suggestion_skipped
  #   @return [::Boolean]
  #     Indicates that invalid items were skipped when parsing the LLM response.
  # @!attribute [rw] primary_query_redacted_and_replaced
  #   @return [::Boolean]
  #     True if the primary suggested query was redacted and replaced by an
  #     additional query.
  # @!attribute [rw] appended_search_context_count
  #   @return [::Integer]
  #     The number of search contexts appended to the query.
  class KnowledgeAssistBehavior
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Reason for query generation failure.
  module QueryGenerationFailureReason
    # Default value.
    QUERY_GENERATION_FAILURE_REASON_UNSPECIFIED = 0

    # Query generation is blocked due to out of quota.
    QUERY_GENERATION_OUT_OF_QUOTA = 1

    # Call to Knowedge Assist query generation model fails.
    QUERY_GENERATION_FAILED = 2

    # Query generation model decides that there is no new topic change or
    # there has been similar queries generated in the previous turns.
    QUERY_GENERATION_NO_QUERY_GENERATED = 3

    # Knowedge Assist generated query is blocked by RAI (Responsible AI).
    QUERY_GENERATION_RAI_FAILED = 4

    # Query generation is blocked by Knowledge Assist conversation profile
    # level / agent id level filtering.
    NOT_IN_ALLOWLIST = 5

    # The generated query is blocked due to redaction.
    QUERY_GENERATION_QUERY_REDACTED = 6

    # Query generation failed due to LLM response parse failure.
    QUERY_GENERATION_LLM_RESPONSE_PARSE_FAILED = 10

    # The conversation has no messages.
    QUERY_GENERATION_EMPTY_CONVERSATION = 11

    # The last message in the conversation is empty.
    QUERY_GENERATION_EMPTY_LAST_MESSAGE = 12

    # The trigger event condition is not met.
    # This occurs in the following scenarios:
    # 1. The trigger_event is CUSTOMER_MESSAGE or UNSPECIFIED, but the last
    #    message is not from the customer.
    # 2. The trigger_event is AGENT_MESSAGE, but the last message is not from
    #    the agent.
    QUERY_GENERATION_TRIGGERING_EVENT_CONDITION_NOT_MET = 13
  end

  # Reason for query categorization failure.
  module QueryCategorizationFailureReason
    # Default value.
    QUERY_CATEGORIZATION_FAILURE_REASON_UNSPECIFIED = 0

    # Vertex AI Search config supplied for query categorization is invalid.
    QUERY_CATEGORIZATION_INVALID_CONFIG = 1

    # Vertex AI Search result does not contain a query categorization result.
    QUERY_CATEGORIZATION_RESULT_NOT_FOUND = 2

    # Vertex AI Search call fails.
    QUERY_CATEGORIZATION_FAILED = 3
  end
end

#query_generation_failure_reason::Google::Cloud::Dialogflow::V2::KnowledgeAssistDebugInfo::QueryGenerationFailureReason

Returns Reason for query generation.



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1347

class KnowledgeAssistDebugInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configured behaviors for Knowedge Assist.
  # @!attribute [rw] answer_generation_rewriter_on
  #   @return [::Boolean]
  #     Whether data store agent rewriter was turned off for the request.
  # @!attribute [rw] end_user_metadata_included
  #   @return [::Boolean]
  #     Whether end_user_metadata is included in the data store agent call.
  # @!attribute [rw] return_query_only
  #   @return [::Boolean]
  #     Whether customers configured to return query only in the
  #     conversation profile.
  # @!attribute [rw] use_pubsub_delivery
  #   @return [::Boolean]
  #     Whether customers configured to use pubsub to deliver.
  # @!attribute [rw] disable_sync_delivery
  #   @return [::Boolean]
  #     Whether customers configured to disable the synchronous delivery of
  #     Knowedge Assist response.
  # @!attribute [rw] previous_queries_included
  #   @return [::Boolean]
  #     Whether previously suggested queries are included in the query generation
  #     process.
  # @!attribute [rw] use_translated_message
  #   @return [::Boolean]
  #     Translated message is included in query generation process.
  # @!attribute [rw] use_custom_safety_filter_level
  #   @return [::Boolean]
  #     Safety filter is adjusted by user.
  # @!attribute [rw] conversation_transcript_has_mixed_languages
  #   @return [::Boolean]
  #     Conversation transcript has mixed languages.
  # @!attribute [rw] query_generation_agent_language_mismatch
  #   @return [::Boolean]
  #     Whether the agent language from the translation generator mismatches the
  #     end-user language.
  # @!attribute [rw] query_generation_end_user_language_mismatch
  #   @return [::Boolean]
  #     Whether the end-user language from the translation generator mismatches
  #     the end-user language.
  # @!attribute [rw] third_party_connector_allowed
  #   @return [::Boolean]
  #     This field indicates whether third party connectors are enabled for the
  #     project
  # @!attribute [rw] multiple_queries_generated
  #   @return [::Boolean]
  #     Indicates that the query generation model generated multiple queries.
  # @!attribute [rw] query_contained_search_context
  #   @return [::Boolean]
  #     Indicates that the generated query contains search context.
  # @!attribute [rw] invalid_items_query_suggestion_skipped
  #   @return [::Boolean]
  #     Indicates that invalid items were skipped when parsing the LLM response.
  # @!attribute [rw] primary_query_redacted_and_replaced
  #   @return [::Boolean]
  #     True if the primary suggested query was redacted and replaced by an
  #     additional query.
  # @!attribute [rw] appended_search_context_count
  #   @return [::Integer]
  #     The number of search contexts appended to the query.
  class KnowledgeAssistBehavior
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Reason for query generation failure.
  module QueryGenerationFailureReason
    # Default value.
    QUERY_GENERATION_FAILURE_REASON_UNSPECIFIED = 0

    # Query generation is blocked due to out of quota.
    QUERY_GENERATION_OUT_OF_QUOTA = 1

    # Call to Knowedge Assist query generation model fails.
    QUERY_GENERATION_FAILED = 2

    # Query generation model decides that there is no new topic change or
    # there has been similar queries generated in the previous turns.
    QUERY_GENERATION_NO_QUERY_GENERATED = 3

    # Knowedge Assist generated query is blocked by RAI (Responsible AI).
    QUERY_GENERATION_RAI_FAILED = 4

    # Query generation is blocked by Knowledge Assist conversation profile
    # level / agent id level filtering.
    NOT_IN_ALLOWLIST = 5

    # The generated query is blocked due to redaction.
    QUERY_GENERATION_QUERY_REDACTED = 6

    # Query generation failed due to LLM response parse failure.
    QUERY_GENERATION_LLM_RESPONSE_PARSE_FAILED = 10

    # The conversation has no messages.
    QUERY_GENERATION_EMPTY_CONVERSATION = 11

    # The last message in the conversation is empty.
    QUERY_GENERATION_EMPTY_LAST_MESSAGE = 12

    # The trigger event condition is not met.
    # This occurs in the following scenarios:
    # 1. The trigger_event is CUSTOMER_MESSAGE or UNSPECIFIED, but the last
    #    message is not from the customer.
    # 2. The trigger_event is AGENT_MESSAGE, but the last message is not from
    #    the agent.
    QUERY_GENERATION_TRIGGERING_EVENT_CONDITION_NOT_MET = 13
  end

  # Reason for query categorization failure.
  module QueryCategorizationFailureReason
    # Default value.
    QUERY_CATEGORIZATION_FAILURE_REASON_UNSPECIFIED = 0

    # Vertex AI Search config supplied for query categorization is invalid.
    QUERY_CATEGORIZATION_INVALID_CONFIG = 1

    # Vertex AI Search result does not contain a query categorization result.
    QUERY_CATEGORIZATION_RESULT_NOT_FOUND = 2

    # Vertex AI Search call fails.
    QUERY_CATEGORIZATION_FAILED = 3
  end
end

#service_latency::Google::Cloud::Dialogflow::V2::ServiceLatency

Returns The latency of the service.

Returns:



1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1347

class KnowledgeAssistDebugInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configured behaviors for Knowedge Assist.
  # @!attribute [rw] answer_generation_rewriter_on
  #   @return [::Boolean]
  #     Whether data store agent rewriter was turned off for the request.
  # @!attribute [rw] end_user_metadata_included
  #   @return [::Boolean]
  #     Whether end_user_metadata is included in the data store agent call.
  # @!attribute [rw] return_query_only
  #   @return [::Boolean]
  #     Whether customers configured to return query only in the
  #     conversation profile.
  # @!attribute [rw] use_pubsub_delivery
  #   @return [::Boolean]
  #     Whether customers configured to use pubsub to deliver.
  # @!attribute [rw] disable_sync_delivery
  #   @return [::Boolean]
  #     Whether customers configured to disable the synchronous delivery of
  #     Knowedge Assist response.
  # @!attribute [rw] previous_queries_included
  #   @return [::Boolean]
  #     Whether previously suggested queries are included in the query generation
  #     process.
  # @!attribute [rw] use_translated_message
  #   @return [::Boolean]
  #     Translated message is included in query generation process.
  # @!attribute [rw] use_custom_safety_filter_level
  #   @return [::Boolean]
  #     Safety filter is adjusted by user.
  # @!attribute [rw] conversation_transcript_has_mixed_languages
  #   @return [::Boolean]
  #     Conversation transcript has mixed languages.
  # @!attribute [rw] query_generation_agent_language_mismatch
  #   @return [::Boolean]
  #     Whether the agent language from the translation generator mismatches the
  #     end-user language.
  # @!attribute [rw] query_generation_end_user_language_mismatch
  #   @return [::Boolean]
  #     Whether the end-user language from the translation generator mismatches
  #     the end-user language.
  # @!attribute [rw] third_party_connector_allowed
  #   @return [::Boolean]
  #     This field indicates whether third party connectors are enabled for the
  #     project
  # @!attribute [rw] multiple_queries_generated
  #   @return [::Boolean]
  #     Indicates that the query generation model generated multiple queries.
  # @!attribute [rw] query_contained_search_context
  #   @return [::Boolean]
  #     Indicates that the generated query contains search context.
  # @!attribute [rw] invalid_items_query_suggestion_skipped
  #   @return [::Boolean]
  #     Indicates that invalid items were skipped when parsing the LLM response.
  # @!attribute [rw] primary_query_redacted_and_replaced
  #   @return [::Boolean]
  #     True if the primary suggested query was redacted and replaced by an
  #     additional query.
  # @!attribute [rw] appended_search_context_count
  #   @return [::Integer]
  #     The number of search contexts appended to the query.
  class KnowledgeAssistBehavior
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Reason for query generation failure.
  module QueryGenerationFailureReason
    # Default value.
    QUERY_GENERATION_FAILURE_REASON_UNSPECIFIED = 0

    # Query generation is blocked due to out of quota.
    QUERY_GENERATION_OUT_OF_QUOTA = 1

    # Call to Knowedge Assist query generation model fails.
    QUERY_GENERATION_FAILED = 2

    # Query generation model decides that there is no new topic change or
    # there has been similar queries generated in the previous turns.
    QUERY_GENERATION_NO_QUERY_GENERATED = 3

    # Knowedge Assist generated query is blocked by RAI (Responsible AI).
    QUERY_GENERATION_RAI_FAILED = 4

    # Query generation is blocked by Knowledge Assist conversation profile
    # level / agent id level filtering.
    NOT_IN_ALLOWLIST = 5

    # The generated query is blocked due to redaction.
    QUERY_GENERATION_QUERY_REDACTED = 6

    # Query generation failed due to LLM response parse failure.
    QUERY_GENERATION_LLM_RESPONSE_PARSE_FAILED = 10

    # The conversation has no messages.
    QUERY_GENERATION_EMPTY_CONVERSATION = 11

    # The last message in the conversation is empty.
    QUERY_GENERATION_EMPTY_LAST_MESSAGE = 12

    # The trigger event condition is not met.
    # This occurs in the following scenarios:
    # 1. The trigger_event is CUSTOMER_MESSAGE or UNSPECIFIED, but the last
    #    message is not from the customer.
    # 2. The trigger_event is AGENT_MESSAGE, but the last message is not from
    #    the agent.
    QUERY_GENERATION_TRIGGERING_EVENT_CONDITION_NOT_MET = 13
  end

  # Reason for query categorization failure.
  module QueryCategorizationFailureReason
    # Default value.
    QUERY_CATEGORIZATION_FAILURE_REASON_UNSPECIFIED = 0

    # Vertex AI Search config supplied for query categorization is invalid.
    QUERY_CATEGORIZATION_INVALID_CONFIG = 1

    # Vertex AI Search result does not contain a query categorization result.
    QUERY_CATEGORIZATION_RESULT_NOT_FOUND = 2

    # Vertex AI Search call fails.
    QUERY_CATEGORIZATION_FAILED = 3
  end
end