Class: Google::Cloud::Dialogflow::V2::KnowledgeAssistDebugInfo::KnowledgeAssistBehavior
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::KnowledgeAssistDebugInfo::KnowledgeAssistBehavior
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/participant.rb
Overview
Configured behaviors for Knowedge Assist.
Instance Attribute Summary collapse
-
#answer_generation_rewriter_on ⇒ ::Boolean
Whether data store agent rewriter was turned off for the request.
-
#appended_search_context_count ⇒ ::Integer
The number of search contexts appended to the query.
-
#conversation_transcript_has_mixed_languages ⇒ ::Boolean
Conversation transcript has mixed languages.
-
#disable_sync_delivery ⇒ ::Boolean
Whether customers configured to disable the synchronous delivery of Knowedge Assist response.
-
#end_user_metadata_included ⇒ ::Boolean
Whether end_user_metadata is included in the data store agent call.
-
#invalid_items_query_suggestion_skipped ⇒ ::Boolean
Indicates that invalid items were skipped when parsing the LLM response.
-
#multiple_queries_generated ⇒ ::Boolean
Indicates that the query generation model generated multiple queries.
-
#previous_queries_included ⇒ ::Boolean
Whether previously suggested queries are included in the query generation process.
-
#primary_query_redacted_and_replaced ⇒ ::Boolean
True if the primary suggested query was redacted and replaced by an additional query.
-
#query_contained_search_context ⇒ ::Boolean
Indicates that the generated query contains search context.
-
#query_generation_agent_language_mismatch ⇒ ::Boolean
Whether the agent language from the translation generator mismatches the end-user language.
-
#query_generation_end_user_language_mismatch ⇒ ::Boolean
Whether the end-user language from the translation generator mismatches the end-user language.
-
#return_query_only ⇒ ::Boolean
Whether customers configured to return query only in the conversation profile.
-
#third_party_connector_allowed ⇒ ::Boolean
This field indicates whether third party connectors are enabled for the project.
-
#use_custom_safety_filter_level ⇒ ::Boolean
Safety filter is adjusted by user.
-
#use_pubsub_delivery ⇒ ::Boolean
Whether customers configured to use pubsub to deliver.
-
#use_translated_message ⇒ ::Boolean
Translated message is included in query generation process.
Instance Attribute Details
#answer_generation_rewriter_on ⇒ ::Boolean
Returns Whether data store agent rewriter was turned off for the request.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#appended_search_context_count ⇒ ::Integer
Returns The number of search contexts appended to the query.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#conversation_transcript_has_mixed_languages ⇒ ::Boolean
Returns Conversation transcript has mixed languages.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#disable_sync_delivery ⇒ ::Boolean
Returns Whether customers configured to disable the synchronous delivery of Knowedge Assist response.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_user_metadata_included ⇒ ::Boolean
Returns Whether end_user_metadata is included in the data store agent call.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#invalid_items_query_suggestion_skipped ⇒ ::Boolean
Returns Indicates that invalid items were skipped when parsing the LLM response.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#multiple_queries_generated ⇒ ::Boolean
Returns Indicates that the query generation model generated multiple queries.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#previous_queries_included ⇒ ::Boolean
Returns Whether previously suggested queries are included in the query generation process.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#primary_query_redacted_and_replaced ⇒ ::Boolean
Returns True if the primary suggested query was redacted and replaced by an additional query.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query_contained_search_context ⇒ ::Boolean
Returns Indicates that the generated query contains search context.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query_generation_agent_language_mismatch ⇒ ::Boolean
Returns Whether the agent language from the translation generator mismatches the end-user language.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query_generation_end_user_language_mismatch ⇒ ::Boolean
Returns Whether the end-user language from the translation generator mismatches the end-user language.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#return_query_only ⇒ ::Boolean
Returns Whether customers configured to return query only in the conversation profile.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#third_party_connector_allowed ⇒ ::Boolean
Returns This field indicates whether third party connectors are enabled for the project.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#use_custom_safety_filter_level ⇒ ::Boolean
Returns Safety filter is adjusted by user.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#use_pubsub_delivery ⇒ ::Boolean
Returns Whether customers configured to use pubsub to deliver.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#use_translated_message ⇒ ::Boolean
Returns Translated message is included in query generation process.
1410 1411 1412 1413 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1410 class KnowledgeAssistBehavior include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |