Class: Google::Cloud::Dialogflow::V2::KnowledgeAssistDebugInfo::QueryGenerationDebugInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::KnowledgeAssistDebugInfo::QueryGenerationDebugInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/participant.rb
Overview
Token usage metadata for query generation.
Instance Attribute Summary collapse
-
#candidates_token_count ⇒ ::Integer
The total number of tokens in the generated candidates.
-
#prompt_token_count ⇒ ::Integer
The total number of tokens in the prompt.
-
#total_token_count ⇒ ::Integer
The total number of tokens for the entire request.
Instance Attribute Details
#candidates_token_count ⇒ ::Integer
Returns The total number of tokens in the generated candidates.
1444 1445 1446 1447 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1444 class QueryGenerationDebugInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#prompt_token_count ⇒ ::Integer
Returns The total number of tokens in the prompt.
1444 1445 1446 1447 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1444 class QueryGenerationDebugInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_token_count ⇒ ::Integer
Returns The total number of tokens for the entire request.
1444 1445 1446 1447 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1444 class QueryGenerationDebugInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |