Class: Google::Cloud::Dialogflow::V2::ListSipTrunksResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::ListSipTrunksResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/sip_trunk.rb
Overview
The response message for SipTrunks.ListSipTrunks.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#sip_trunks ⇒ ::Array<::Google::Cloud::Dialogflow::V2::SipTrunk>
The list of SIP trunks.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns Token to retrieve the next page of results, or empty if there are no more results in the list.
77 78 79 80 |
# File 'proto_docs/google/cloud/dialogflow/v2/sip_trunk.rb', line 77 class ListSipTrunksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sip_trunks ⇒ ::Array<::Google::Cloud::Dialogflow::V2::SipTrunk>
Returns The list of SIP trunks.
77 78 79 80 |
# File 'proto_docs/google/cloud/dialogflow/v2/sip_trunk.rb', line 77 class ListSipTrunksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |