Class: Google::Cloud::Dialogflow::V2::SearchKnowledgeAnswer
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::SearchKnowledgeAnswer
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/conversation.rb
Overview
Represents a SearchKnowledge answer.
Defined Under Namespace
Modules: AnswerType Classes: AnswerSource
Instance Attribute Summary collapse
-
#answer ⇒ ::String
The piece of text from the knowledge base documents that answers the search query.
-
#answer_record ⇒ ::String
The name of the answer record.
-
#answer_sources ⇒ ::Array<::Google::Cloud::Dialogflow::V2::SearchKnowledgeAnswer::AnswerSource>
All sources used to generate the answer.
-
#answer_type ⇒ ::Google::Cloud::Dialogflow::V2::SearchKnowledgeAnswer::AnswerType
The type of the answer.
Instance Attribute Details
#answer ⇒ ::String
Returns The piece of text from the knowledge base documents that answers the search query.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1080 class SearchKnowledgeAnswer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The sources of the answers. # @!attribute [rw] title # @return [::String] # The title of the article. # @!attribute [rw] uri # @return [::String] # The URI of the article. # @!attribute [rw] snippet # @return [::String] # The relevant snippet of the article. # @!attribute [rw] metadata # @return [::Google::Protobuf::Struct] # Metadata associated with the article. class AnswerSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the answer. module AnswerType # The answer has a unspecified type. ANSWER_TYPE_UNSPECIFIED = 0 # The answer is from FAQ documents. FAQ = 1 # The answer is from generative model. GENERATIVE = 2 # The answer is from intent matching. INTENT = 3 end end |
#answer_record ⇒ ::String
Returns The name of the answer record.
Format: projects/<Project ID>/locations/<location ID>/answer
Records/<Answer Record ID>.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1080 class SearchKnowledgeAnswer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The sources of the answers. # @!attribute [rw] title # @return [::String] # The title of the article. # @!attribute [rw] uri # @return [::String] # The URI of the article. # @!attribute [rw] snippet # @return [::String] # The relevant snippet of the article. # @!attribute [rw] metadata # @return [::Google::Protobuf::Struct] # Metadata associated with the article. class AnswerSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the answer. module AnswerType # The answer has a unspecified type. ANSWER_TYPE_UNSPECIFIED = 0 # The answer is from FAQ documents. FAQ = 1 # The answer is from generative model. GENERATIVE = 2 # The answer is from intent matching. INTENT = 3 end end |
#answer_sources ⇒ ::Array<::Google::Cloud::Dialogflow::V2::SearchKnowledgeAnswer::AnswerSource>
Returns All sources used to generate the answer.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1080 class SearchKnowledgeAnswer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The sources of the answers. # @!attribute [rw] title # @return [::String] # The title of the article. # @!attribute [rw] uri # @return [::String] # The URI of the article. # @!attribute [rw] snippet # @return [::String] # The relevant snippet of the article. # @!attribute [rw] metadata # @return [::Google::Protobuf::Struct] # Metadata associated with the article. class AnswerSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the answer. module AnswerType # The answer has a unspecified type. ANSWER_TYPE_UNSPECIFIED = 0 # The answer is from FAQ documents. FAQ = 1 # The answer is from generative model. GENERATIVE = 2 # The answer is from intent matching. INTENT = 3 end end |
#answer_type ⇒ ::Google::Cloud::Dialogflow::V2::SearchKnowledgeAnswer::AnswerType
Returns The type of the answer.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1080 class SearchKnowledgeAnswer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The sources of the answers. # @!attribute [rw] title # @return [::String] # The title of the article. # @!attribute [rw] uri # @return [::String] # The URI of the article. # @!attribute [rw] snippet # @return [::String] # The relevant snippet of the article. # @!attribute [rw] metadata # @return [::Google::Protobuf::Struct] # Metadata associated with the article. class AnswerSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the answer. module AnswerType # The answer has a unspecified type. ANSWER_TYPE_UNSPECIFIED = 0 # The answer is from FAQ documents. FAQ = 1 # The answer is from generative model. GENERATIVE = 2 # The answer is from intent matching. INTENT = 3 end end |