Class: Google::Cloud::Dialogflow::V2::SearchKnowledgeDebugInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/conversation.rb

Overview

Debug information related to SearchKnowledge feature.

Defined Under Namespace

Classes: SearchKnowledgeBehavior

Instance Attribute Summary collapse

Instance Attribute Details

#datastore_response_reason::Google::Cloud::Dialogflow::V2::DatastoreResponseReason

Returns Response reason from datastore which indicates data serving status or answer quality degradation.

Returns:



1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1025

class SearchKnowledgeDebugInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configured behaviors for SearchKnowledge.
  # @!attribute [rw] answer_generation_rewriter_on
  #   @return [::Boolean]
  #     Whether data store agent rewriter was turned on for the request.
  # @!attribute [rw] end_user_metadata_included
  #   @return [::Boolean]
  #     Whether end_user_metadata is included in the data store agent call.
  # @!attribute [rw] third_party_connector_allowed
  #   @return [::Boolean]
  #     This field indicates whether third party connectors are enabled for the
  #     project. Note that this field only indicates if the project is
  #     allowlisted for connectors.
  class SearchKnowledgeBehavior
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#ingested_context_reference_debug_info::Google::Cloud::Dialogflow::V2::IngestedContextReferenceDebugInfo

Returns Information about parameters ingested for search knowledge.

Returns:



1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1025

class SearchKnowledgeDebugInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configured behaviors for SearchKnowledge.
  # @!attribute [rw] answer_generation_rewriter_on
  #   @return [::Boolean]
  #     Whether data store agent rewriter was turned on for the request.
  # @!attribute [rw] end_user_metadata_included
  #   @return [::Boolean]
  #     Whether end_user_metadata is included in the data store agent call.
  # @!attribute [rw] third_party_connector_allowed
  #   @return [::Boolean]
  #     This field indicates whether third party connectors are enabled for the
  #     project. Note that this field only indicates if the project is
  #     allowlisted for connectors.
  class SearchKnowledgeBehavior
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#search_knowledge_behavior::Google::Cloud::Dialogflow::V2::SearchKnowledgeDebugInfo::SearchKnowledgeBehavior

Returns Configured behaviors for SearchKnowledge.

Returns:



1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1025

class SearchKnowledgeDebugInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configured behaviors for SearchKnowledge.
  # @!attribute [rw] answer_generation_rewriter_on
  #   @return [::Boolean]
  #     Whether data store agent rewriter was turned on for the request.
  # @!attribute [rw] end_user_metadata_included
  #   @return [::Boolean]
  #     Whether end_user_metadata is included in the data store agent call.
  # @!attribute [rw] third_party_connector_allowed
  #   @return [::Boolean]
  #     This field indicates whether third party connectors are enabled for the
  #     project. Note that this field only indicates if the project is
  #     allowlisted for connectors.
  class SearchKnowledgeBehavior
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#service_latency::Google::Cloud::Dialogflow::V2::ServiceLatency

Returns The latency of the service.

Returns:



1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1025

class SearchKnowledgeDebugInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configured behaviors for SearchKnowledge.
  # @!attribute [rw] answer_generation_rewriter_on
  #   @return [::Boolean]
  #     Whether data store agent rewriter was turned on for the request.
  # @!attribute [rw] end_user_metadata_included
  #   @return [::Boolean]
  #     Whether end_user_metadata is included in the data store agent call.
  # @!attribute [rw] third_party_connector_allowed
  #   @return [::Boolean]
  #     This field indicates whether third party connectors are enabled for the
  #     project. Note that this field only indicates if the project is
  #     allowlisted for connectors.
  class SearchKnowledgeBehavior
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end