Class: Google::Cloud::Dialogflow::V2::SearchKnowledgeDebugInfo::SearchKnowledgeBehavior

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/conversation.rb

Overview

Configured behaviors for SearchKnowledge.

Instance Attribute Summary collapse

Instance Attribute Details

#answer_generation_rewriter_on::Boolean

Returns Whether data store agent rewriter was turned on for the request.

Returns:

  • (::Boolean)

    Whether data store agent rewriter was turned on for the request.



1041
1042
1043
1044
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1041

class SearchKnowledgeBehavior
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#end_user_metadata_included::Boolean

Returns Whether end_user_metadata is included in the data store agent call.

Returns:

  • (::Boolean)

    Whether end_user_metadata is included in the data store agent call.



1041
1042
1043
1044
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1041

class SearchKnowledgeBehavior
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#third_party_connector_allowed::Boolean

Returns This field indicates whether third party connectors are enabled for the project. Note that this field only indicates if the project is allowlisted for connectors.

Returns:

  • (::Boolean)

    This field indicates whether third party connectors are enabled for the project. Note that this field only indicates if the project is allowlisted for connectors.



1041
1042
1043
1044
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 1041

class SearchKnowledgeBehavior
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end