Class: Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/conversation.rb
Overview
Boost applies to documents which match a condition.
Defined Under Namespace
Classes: BoostControlSpec
Instance Attribute Summary collapse
-
#boost ⇒ ::Float
Optional.
-
#boost_control_spec ⇒ ::Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec::BoostControlSpec
Optional.
-
#condition ⇒ ::String
Optional.
Instance Attribute Details
#boost ⇒ ::Float
Returns Optional. Strength of the condition boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0.
Setting to 1.0 gives the document a big promotion. However, it does not necessarily mean that the boosted document will be the top result at all times, nor that other documents will be excluded. Results could still be shown even when none of them matches the condition. And results that are significantly more relevant to the search query can still trump your heavily favored but irrelevant documents.
Setting to -1.0 gives the document a big demotion. However, results that are deeply relevant might still be shown. The document will have an upstream battle to get a fairly high ranking, but it is not blocked out completely.
Setting to 0.0 means no boost applied. The boosting condition is ignored.
886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 886 class ConditionBoostSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specification for custom ranking based on customer specified # attribute # value. It provides more controls for customized ranking than the # simple (condition, boost) combination above. # @!attribute [rw] field_name # @return [::String] # Optional. The name of the field whose value will be used to # determine the boost amount. # @!attribute [rw] attribute_type # @return [::Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec::BoostControlSpec::AttributeType] # Optional. The attribute type to be used to determine the boost # amount. The attribute value can be derived from the field value # of the specified field_name. In the case of numerical it is # straightforward i.e. attribute_value = numerical_field_value. In # the case of freshness however, attribute_value = (time.now() - # datetime_field_value). # @!attribute [rw] interpolation_type # @return [::Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec::BoostControlSpec::InterpolationType] # Optional. The interpolation type to be applied to connect the # control points listed below. # @!attribute [rw] control_points # @return [::Array<::Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec::BoostControlSpec::ControlPoint>] # Optional. The control points used to define the curve. The # monotonic function (defined through the interpolation_type above) # passes through the control points listed here. class BoostControlSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The control points used to define the curve. The curve defined # through these control points can only be monotonically increasing # or decreasing(constant values are acceptable). # @!attribute [rw] attribute_value # @return [::String] # Optional. Can be one of: # 1. The numerical field value. # 2. The duration spec for freshness: # The value must be formatted as an XSD `dayTimeDuration` value # (a restricted subset of an ISO 8601 duration value). The # pattern for this is: `[nD][T[nH][nM][nS]]`. # @!attribute [rw] boost_amount # @return [::Float] # Optional. The value between -1 to 1 by which to boost the score # if the attribute_value evaluates to the value specified above. class ControlPoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The attribute(or function) for which the custom ranking is to be # applied. module AttributeType # Unspecified AttributeType. ATTRIBUTE_TYPE_UNSPECIFIED = 0 # The value of the numerical field will be used to dynamically # update the boost amount. In this case, the attribute_value (the # x value) of the control point will be the actual value of the # numerical field for which the boost_amount is specified. NUMERICAL = 1 # For the freshness use case the attribute value will be the # duration between the current time and the date in the datetime # field specified. The value must be formatted as an XSD # `dayTimeDuration` value (a restricted subset of an ISO 8601 # duration value). The pattern for this is: # `[nD][T[nH][nM][nS]]`. E.g. `5D`, `3DT12H30M`, `T24H`. FRESHNESS = 2 end # The interpolation type to be applied. Default will be linear # (Piecewise Linear). module InterpolationType # Interpolation type is unspecified. In this case, it defaults to # Linear. INTERPOLATION_TYPE_UNSPECIFIED = 0 # Piecewise linear interpolation will be applied. LINEAR = 1 end end end |
#boost_control_spec ⇒ ::Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec::BoostControlSpec
Returns Optional. Complex specification for custom ranking based on customer defined attribute value.
886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 886 class ConditionBoostSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specification for custom ranking based on customer specified # attribute # value. It provides more controls for customized ranking than the # simple (condition, boost) combination above. # @!attribute [rw] field_name # @return [::String] # Optional. The name of the field whose value will be used to # determine the boost amount. # @!attribute [rw] attribute_type # @return [::Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec::BoostControlSpec::AttributeType] # Optional. The attribute type to be used to determine the boost # amount. The attribute value can be derived from the field value # of the specified field_name. In the case of numerical it is # straightforward i.e. attribute_value = numerical_field_value. In # the case of freshness however, attribute_value = (time.now() - # datetime_field_value). # @!attribute [rw] interpolation_type # @return [::Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec::BoostControlSpec::InterpolationType] # Optional. The interpolation type to be applied to connect the # control points listed below. # @!attribute [rw] control_points # @return [::Array<::Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec::BoostControlSpec::ControlPoint>] # Optional. The control points used to define the curve. The # monotonic function (defined through the interpolation_type above) # passes through the control points listed here. class BoostControlSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The control points used to define the curve. The curve defined # through these control points can only be monotonically increasing # or decreasing(constant values are acceptable). # @!attribute [rw] attribute_value # @return [::String] # Optional. Can be one of: # 1. The numerical field value. # 2. The duration spec for freshness: # The value must be formatted as an XSD `dayTimeDuration` value # (a restricted subset of an ISO 8601 duration value). The # pattern for this is: `[nD][T[nH][nM][nS]]`. # @!attribute [rw] boost_amount # @return [::Float] # Optional. The value between -1 to 1 by which to boost the score # if the attribute_value evaluates to the value specified above. class ControlPoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The attribute(or function) for which the custom ranking is to be # applied. module AttributeType # Unspecified AttributeType. ATTRIBUTE_TYPE_UNSPECIFIED = 0 # The value of the numerical field will be used to dynamically # update the boost amount. In this case, the attribute_value (the # x value) of the control point will be the actual value of the # numerical field for which the boost_amount is specified. NUMERICAL = 1 # For the freshness use case the attribute value will be the # duration between the current time and the date in the datetime # field specified. The value must be formatted as an XSD # `dayTimeDuration` value (a restricted subset of an ISO 8601 # duration value). The pattern for this is: # `[nD][T[nH][nM][nS]]`. E.g. `5D`, `3DT12H30M`, `T24H`. FRESHNESS = 2 end # The interpolation type to be applied. Default will be linear # (Piecewise Linear). module InterpolationType # Interpolation type is unspecified. In this case, it defaults to # Linear. INTERPOLATION_TYPE_UNSPECIFIED = 0 # Piecewise linear interpolation will be applied. LINEAR = 1 end end end |
#condition ⇒ ::String
Returns Optional. An expression which specifies a boost condition. The syntax and supported fields are the same as a filter expression. Examples:
- To boost documents with document ID "doc_1" or "doc_2", and
color
"Red" or "Blue":
- (id: ANY("doc_1", "doc_2")) AND (color: ANY("Red","Blue")).
886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 886 class ConditionBoostSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specification for custom ranking based on customer specified # attribute # value. It provides more controls for customized ranking than the # simple (condition, boost) combination above. # @!attribute [rw] field_name # @return [::String] # Optional. The name of the field whose value will be used to # determine the boost amount. # @!attribute [rw] attribute_type # @return [::Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec::BoostControlSpec::AttributeType] # Optional. The attribute type to be used to determine the boost # amount. The attribute value can be derived from the field value # of the specified field_name. In the case of numerical it is # straightforward i.e. attribute_value = numerical_field_value. In # the case of freshness however, attribute_value = (time.now() - # datetime_field_value). # @!attribute [rw] interpolation_type # @return [::Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec::BoostControlSpec::InterpolationType] # Optional. The interpolation type to be applied to connect the # control points listed below. # @!attribute [rw] control_points # @return [::Array<::Google::Cloud::Dialogflow::V2::SearchKnowledgeRequest::SearchConfig::BoostSpecs::BoostSpec::ConditionBoostSpec::BoostControlSpec::ControlPoint>] # Optional. The control points used to define the curve. The # monotonic function (defined through the interpolation_type above) # passes through the control points listed here. class BoostControlSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The control points used to define the curve. The curve defined # through these control points can only be monotonically increasing # or decreasing(constant values are acceptable). # @!attribute [rw] attribute_value # @return [::String] # Optional. Can be one of: # 1. The numerical field value. # 2. The duration spec for freshness: # The value must be formatted as an XSD `dayTimeDuration` value # (a restricted subset of an ISO 8601 duration value). The # pattern for this is: `[nD][T[nH][nM][nS]]`. # @!attribute [rw] boost_amount # @return [::Float] # Optional. The value between -1 to 1 by which to boost the score # if the attribute_value evaluates to the value specified above. class ControlPoint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The attribute(or function) for which the custom ranking is to be # applied. module AttributeType # Unspecified AttributeType. ATTRIBUTE_TYPE_UNSPECIFIED = 0 # The value of the numerical field will be used to dynamically # update the boost amount. In this case, the attribute_value (the # x value) of the control point will be the actual value of the # numerical field for which the boost_amount is specified. NUMERICAL = 1 # For the freshness use case the attribute value will be the # duration between the current time and the date in the datetime # field specified. The value must be formatted as an XSD # `dayTimeDuration` value (a restricted subset of an ISO 8601 # duration value). The pattern for this is: # `[nD][T[nH][nM][nS]]`. E.g. `5D`, `3DT12H30M`, `T24H`. FRESHNESS = 2 end # The interpolation type to be applied. Default will be linear # (Piecewise Linear). module InterpolationType # Interpolation type is unspecified. In this case, it defaults to # Linear. INTERPOLATION_TYPE_UNSPECIFIED = 0 # Piecewise linear interpolation will be applied. LINEAR = 1 end end end |