Class: Google::Cloud::Dialogflow::V2::ServiceLatency::InternalServiceLatency
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::ServiceLatency::InternalServiceLatency
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/participant.rb
Overview
Message to represent the latency of an internal service.
Instance Attribute Summary collapse
-
#complete_time ⇒ ::Google::Protobuf::Timestamp
The completion time of the internal service.
-
#latency_ms ⇒ ::Float
The latency of the internal service in milliseconds.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
The start time of the internal service.
-
#step ⇒ ::String
The name of the internal service.
Instance Attribute Details
#complete_time ⇒ ::Google::Protobuf::Timestamp
Returns The completion time of the internal service.
1321 1322 1323 1324 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1321 class InternalServiceLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#latency_ms ⇒ ::Float
Returns The latency of the internal service in milliseconds.
1321 1322 1323 1324 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1321 class InternalServiceLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns The start time of the internal service.
1321 1322 1323 1324 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1321 class InternalServiceLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#step ⇒ ::String
Returns The name of the internal service.
1321 1322 1323 1324 |
# File 'proto_docs/google/cloud/dialogflow/v2/participant.rb', line 1321 class InternalServiceLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |