Class: Google::Cloud::Dialogflow::V2::SipConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::SipConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb
Overview
Defines the SIP configuration.
Instance Attribute Summary collapse
-
#allow_virtual_agent_interaction ⇒ ::Boolean
Allows interactions with a Dialogflow virtual agent even if the call is connected for SIPREC purposes.
-
#copy_inbound_call_leg_headers ⇒ ::Array<::String>
List of inbound call leg headers to be copied to outbound call legs created later.
-
#create_conversation_on_the_fly ⇒ ::Boolean
Asks Dialogflow Telephony to create the conversation provided in the SIP header on the fly when the call comes in.
-
#ignore_reinvite_media_direction ⇒ ::Boolean
Ignores any media direction in the reINVITE SDP offer.
-
#inactive_start ⇒ ::Boolean
Starts the conversation with inactive SDP directives.
-
#keep_conversation_running ⇒ ::Boolean
Keeps the conversation running even if the call is disconnected.
-
#max_audio_recording_duration ⇒ ::Google::Protobuf::Duration
Max duration for audio recording.
Instance Attribute Details
#allow_virtual_agent_interaction ⇒ ::Boolean
Returns Allows interactions with a Dialogflow virtual agent even if the call is connected for SIPREC purposes.
797 798 799 800 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb', line 797 class SipConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#copy_inbound_call_leg_headers ⇒ ::Array<::String>
Returns List of inbound call leg headers to be copied to outbound call legs created later.
797 798 799 800 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb', line 797 class SipConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_conversation_on_the_fly ⇒ ::Boolean
Returns Asks Dialogflow Telephony to create the conversation provided in the SIP header on the fly when the call comes in.
797 798 799 800 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb', line 797 class SipConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ignore_reinvite_media_direction ⇒ ::Boolean
Returns Ignores any media direction in the reINVITE SDP offer. Reuse the previous media direction.
797 798 799 800 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb', line 797 class SipConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#inactive_start ⇒ ::Boolean
Returns Starts the conversation with inactive SDP directives.
797 798 799 800 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb', line 797 class SipConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#keep_conversation_running ⇒ ::Boolean
Returns Keeps the conversation running even if the call is disconnected.
797 798 799 800 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb', line 797 class SipConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_audio_recording_duration ⇒ ::Google::Protobuf::Duration
Returns Max duration for audio recording. Overrides the default value of 15 min. Max value is 8 hours.
797 798 799 800 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb', line 797 class SipConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |