Class: Google::Cloud::Dialogflow::V2::SuggestConversationSummaryResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::SuggestConversationSummaryResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/conversation.rb
Overview
The response message for Conversations.SuggestConversationSummary.
Defined Under Namespace
Classes: Summary
Instance Attribute Summary collapse
-
#context_size ⇒ ::Integer
Number of messages prior to and including latest_message used to compile the suggestion.
-
#latest_message ⇒ ::String
The name of the latest conversation message used as context for compiling suggestion.
-
#summary ⇒ ::Google::Cloud::Dialogflow::V2::SuggestConversationSummaryResponse::Summary
Generated summary.
Instance Attribute Details
#context_size ⇒ ::Integer
Returns Number of messages prior to and including latest_message used to compile the suggestion. It may be smaller than the SuggestConversationSummaryRequest.context_size field in the request if there weren't that many messages in the conversation.
524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 524 class SuggestConversationSummaryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Generated summary for a conversation. # @!attribute [rw] text # @return [::String] # The summary content that is concatenated into one string. # @!attribute [rw] text_sections # @return [::Google::Protobuf::Map{::String => ::String}] # The summary content that is divided into sections. The key is the # section's name and the value is the section's content. There is no # specific format for the key or value. # @!attribute [rw] sorted_text_sections # @return [::Array<::Google::Cloud::Dialogflow::V2::SuggestConversationSummaryResponse::Summary::SummarySection>] # Same as text_sections, but in an order that is consistent with the order # of the sections in the generator. # @!attribute [rw] answer_record # @return [::String] # The name of the answer record. Format: # "projects/<Project ID>/answerRecords/<Answer Record ID>" # @!attribute [rw] baseline_model_version # @return [::String] # The baseline model version used to generate this summary. It is empty if # a baseline model was not used to generate this summary. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A component of the generated summary. # @!attribute [r] section # @return [::String] # Output only. Name of the section. # @!attribute [r] summary # @return [::String] # Output only. Summary text for the section. class SummarySection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TextSectionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#latest_message ⇒ ::String
Returns The name of the latest conversation message used as context for compiling suggestion.
Format: projects/<Project ID>/locations/<Location
ID>/conversations/<Conversation ID>/messages/<Message ID>.
524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 524 class SuggestConversationSummaryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Generated summary for a conversation. # @!attribute [rw] text # @return [::String] # The summary content that is concatenated into one string. # @!attribute [rw] text_sections # @return [::Google::Protobuf::Map{::String => ::String}] # The summary content that is divided into sections. The key is the # section's name and the value is the section's content. There is no # specific format for the key or value. # @!attribute [rw] sorted_text_sections # @return [::Array<::Google::Cloud::Dialogflow::V2::SuggestConversationSummaryResponse::Summary::SummarySection>] # Same as text_sections, but in an order that is consistent with the order # of the sections in the generator. # @!attribute [rw] answer_record # @return [::String] # The name of the answer record. Format: # "projects/<Project ID>/answerRecords/<Answer Record ID>" # @!attribute [rw] baseline_model_version # @return [::String] # The baseline model version used to generate this summary. It is empty if # a baseline model was not used to generate this summary. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A component of the generated summary. # @!attribute [r] section # @return [::String] # Output only. Name of the section. # @!attribute [r] summary # @return [::String] # Output only. Summary text for the section. class SummarySection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TextSectionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#summary ⇒ ::Google::Cloud::Dialogflow::V2::SuggestConversationSummaryResponse::Summary
Returns Generated summary.
524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 524 class SuggestConversationSummaryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Generated summary for a conversation. # @!attribute [rw] text # @return [::String] # The summary content that is concatenated into one string. # @!attribute [rw] text_sections # @return [::Google::Protobuf::Map{::String => ::String}] # The summary content that is divided into sections. The key is the # section's name and the value is the section's content. There is no # specific format for the key or value. # @!attribute [rw] sorted_text_sections # @return [::Array<::Google::Cloud::Dialogflow::V2::SuggestConversationSummaryResponse::Summary::SummarySection>] # Same as text_sections, but in an order that is consistent with the order # of the sections in the generator. # @!attribute [rw] answer_record # @return [::String] # The name of the answer record. Format: # "projects/<Project ID>/answerRecords/<Answer Record ID>" # @!attribute [rw] baseline_model_version # @return [::String] # The baseline model version used to generate this summary. It is empty if # a baseline model was not used to generate this summary. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A component of the generated summary. # @!attribute [r] section # @return [::String] # Output only. Name of the section. # @!attribute [r] summary # @return [::String] # Output only. Summary text for the section. class SummarySection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TextSectionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |