Class: Google::Cloud::Dialogflow::V2::SuggestConversationSummaryResponse::Summary
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::SuggestConversationSummaryResponse::Summary
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/conversation.rb
Overview
Generated summary for a conversation.
Defined Under Namespace
Classes: SummarySection, TextSectionsEntry
Instance Attribute Summary collapse
-
#answer_record ⇒ ::String
The name of the answer record.
-
#baseline_model_version ⇒ ::String
The baseline model version used to generate this summary.
-
#sorted_text_sections ⇒ ::Array<::Google::Cloud::Dialogflow::V2::SuggestConversationSummaryResponse::Summary::SummarySection>
Same as text_sections, but in an order that is consistent with the order of the sections in the generator.
-
#text ⇒ ::String
The summary content that is concatenated into one string.
-
#text_sections ⇒ ::Google::Protobuf::Map{::String => ::String}
The summary content that is divided into sections.
Instance Attribute Details
#answer_record ⇒ ::String
Returns The name of the answer record. Format:
"projects/
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 549 class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A component of the generated summary. # @!attribute [r] section # @return [::String] # Output only. Name of the section. # @!attribute [r] summary # @return [::String] # Output only. Summary text for the section. class SummarySection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TextSectionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#baseline_model_version ⇒ ::String
Returns The baseline model version used to generate this summary. It is empty if a baseline model was not used to generate this summary.
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 549 class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A component of the generated summary. # @!attribute [r] section # @return [::String] # Output only. Name of the section. # @!attribute [r] summary # @return [::String] # Output only. Summary text for the section. class SummarySection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TextSectionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#sorted_text_sections ⇒ ::Array<::Google::Cloud::Dialogflow::V2::SuggestConversationSummaryResponse::Summary::SummarySection>
Returns Same as text_sections, but in an order that is consistent with the order of the sections in the generator.
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 549 class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A component of the generated summary. # @!attribute [r] section # @return [::String] # Output only. Name of the section. # @!attribute [r] summary # @return [::String] # Output only. Summary text for the section. class SummarySection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TextSectionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#text ⇒ ::String
Returns The summary content that is concatenated into one string.
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 549 class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A component of the generated summary. # @!attribute [r] section # @return [::String] # Output only. Name of the section. # @!attribute [r] summary # @return [::String] # Output only. Summary text for the section. class SummarySection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TextSectionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#text_sections ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns The summary content that is divided into sections. The key is the section's name and the value is the section's content. There is no specific format for the key or value.
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'proto_docs/google/cloud/dialogflow/v2/conversation.rb', line 549 class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A component of the generated summary. # @!attribute [r] section # @return [::String] # Output only. Name of the section. # @!attribute [r] summary # @return [::String] # Output only. Summary text for the section. class SummarySection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TextSectionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |