Class: Google::Cloud::Dialogflow::V2::SuggestionFeature

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb

Overview

The type of Human Agent Assistant API suggestion to perform, and the maximum number of results to return for that type. Multiple Feature objects can be specified in the features list.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#type::Google::Cloud::Dialogflow::V2::SuggestionFeature::Type

Returns Type of Human Agent Assistant API feature to request.

Returns:



758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
# File 'proto_docs/google/cloud/dialogflow/v2/conversation_profile.rb', line 758

class SuggestionFeature
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the type of Human Agent Assistant feature.
  module Type
    # Unspecified feature type.
    TYPE_UNSPECIFIED = 0

    # Run article suggestion model for chat.
    ARTICLE_SUGGESTION = 1

    # Run FAQ model for chat.
    FAQ = 2

    # Run smart reply model for chat.
    SMART_REPLY = 3

    # Run conversation summarization model for chat.
    CONVERSATION_SUMMARIZATION = 8

    # Run knowledge search with text input from agent or text generated query.
    KNOWLEDGE_SEARCH = 14

    # Run knowledge assist with automatic query generation.
    KNOWLEDGE_ASSIST = 15
  end
end