Class: Google::Cloud::Dialogflow::V2::SummarizationEvaluationMetrics::AdherenceRubric
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::SummarizationEvaluationMetrics::AdherenceRubric
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/generator_evaluation.rb
Overview
Rubric result of the adherence evaluation. A rubric is ued to determine if the summary adheres to all aspects of the given instructions.
Instance Attribute Summary collapse
-
#is_addressed ⇒ ::Boolean
readonly
Output only.
-
#question ⇒ ::String
readonly
Output only.
-
#reasoning ⇒ ::String
readonly
Output only.
Instance Attribute Details
#is_addressed ⇒ ::Boolean (readonly)
Returns Output only. A boolean that indicates whether the rubric question is addressed or not.
208 209 210 211 |
# File 'proto_docs/google/cloud/dialogflow/v2/generator_evaluation.rb', line 208 class AdherenceRubric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#question ⇒ ::String (readonly)
Returns Output only. The question generated from instruction that used to evaluate summary.
208 209 210 211 |
# File 'proto_docs/google/cloud/dialogflow/v2/generator_evaluation.rb', line 208 class AdherenceRubric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reasoning ⇒ ::String (readonly)
Returns Output only. The reasoning of the rubric question is addressed or not.
208 209 210 211 |
# File 'proto_docs/google/cloud/dialogflow/v2/generator_evaluation.rb', line 208 class AdherenceRubric include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |