Class: Google::Cloud::Dialogflow::V2::ToolCall
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::ToolCall
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/tool_call.rb
Overview
Represents a call of a specific tool's action with the specified inputs.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#action ⇒ ::String
Optional.
-
#answer_record ⇒ ::String
Optional.
-
#ces_app ⇒ ::String
Optional.
-
#ces_tool ⇒ ::String
Optional.
-
#ces_toolset ⇒ ::String
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#input_parameters ⇒ ::Google::Protobuf::Struct
Optional.
-
#state ⇒ ::Google::Cloud::Dialogflow::V2::ToolCall::State
readonly
Output only.
-
#tool ⇒ ::String
Optional.
-
#tool_display_details ⇒ ::String
Optional.
-
#tool_display_name ⇒ ::String
Optional.
Instance Attribute Details
#action ⇒ ::String
Returns Optional. The name of the tool's action associated with this call.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 74 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tool call states. module State # Default value. STATE_UNSPECIFIED = 0 # The tool call has been triggered. TRIGGERED = 1 # The tool call requires confirmation from a human. NEEDS_CONFIRMATION = 2 end end |
#answer_record ⇒ ::String
Returns Optional. The answer record associated with this tool call.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 74 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tool call states. module State # Default value. STATE_UNSPECIFIED = 0 # The tool call has been triggered. TRIGGERED = 1 # The tool call requires confirmation from a human. NEEDS_CONFIRMATION = 2 end end |
#ces_app ⇒ ::String
Returns Optional. CES app name for this call.
Format:
projects/<ProjectID>/locations/<LocationID>/apps/<AppID>.
Note: The following fields are mutually exclusive: ces_app, tool, ces_tool, ces_toolset. If a field in that set is populated, all other fields in the set will automatically be cleared.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 74 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tool call states. module State # Default value. STATE_UNSPECIFIED = 0 # The tool call has been triggered. TRIGGERED = 1 # The tool call requires confirmation from a human. NEEDS_CONFIRMATION = 2 end end |
#ces_tool ⇒ ::String
Returns Optional. CES tool name for this call.
Format:
projects/<ProjectID>/locations/<LocationID>/apps/<AppID>/tools/<ToolID>.
Note: The following fields are mutually exclusive: ces_tool, tool, ces_toolset, ces_app. If a field in that set is populated, all other fields in the set will automatically be cleared.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 74 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tool call states. module State # Default value. STATE_UNSPECIFIED = 0 # The tool call has been triggered. TRIGGERED = 1 # The tool call requires confirmation from a human. NEEDS_CONFIRMATION = 2 end end |
#ces_toolset ⇒ ::String
Returns Optional. CES toolset name for this call.
Format:
projects/<ProjectID>/locations/<LocationID>/apps/<AppID>/toolsets/ToolsetID>.
Note: The following fields are mutually exclusive: ces_toolset, tool, ces_tool, ces_app. If a field in that set is populated, all other fields in the set will automatically be cleared.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 74 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tool call states. module State # Default value. STATE_UNSPECIFIED = 0 # The tool call has been triggered. TRIGGERED = 1 # The tool call requires confirmation from a human. NEEDS_CONFIRMATION = 2 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Create time of the tool call.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 74 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tool call states. module State # Default value. STATE_UNSPECIFIED = 0 # The tool call has been triggered. TRIGGERED = 1 # The tool call requires confirmation from a human. NEEDS_CONFIRMATION = 2 end end |
#input_parameters ⇒ ::Google::Protobuf::Struct
Returns Optional. The action's input parameters.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 74 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tool call states. module State # Default value. STATE_UNSPECIFIED = 0 # The tool call has been triggered. TRIGGERED = 1 # The tool call requires confirmation from a human. NEEDS_CONFIRMATION = 2 end end |
#state ⇒ ::Google::Cloud::Dialogflow::V2::ToolCall::State (readonly)
Returns Output only. State of the tool call.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 74 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tool call states. module State # Default value. STATE_UNSPECIFIED = 0 # The tool call has been triggered. TRIGGERED = 1 # The tool call requires confirmation from a human. NEEDS_CONFIRMATION = 2 end end |
#tool ⇒ ::String
Returns Optional. The tool associated with
this call. Format:
projects/<ProjectID>/locations/<LocationID>/tools/<ToolID>.
Note: The following fields are mutually exclusive: tool, ces_tool, ces_toolset, ces_app. If a field in that set is populated, all other fields in the set will automatically be cleared.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 74 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tool call states. module State # Default value. STATE_UNSPECIFIED = 0 # The tool call has been triggered. TRIGGERED = 1 # The tool call requires confirmation from a human. NEEDS_CONFIRMATION = 2 end end |
#tool_display_details ⇒ ::String
Returns Optional. A human readable description of the tool.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 74 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tool call states. module State # Default value. STATE_UNSPECIFIED = 0 # The tool call has been triggered. TRIGGERED = 1 # The tool call requires confirmation from a human. NEEDS_CONFIRMATION = 2 end end |
#tool_display_name ⇒ ::String
Returns Optional. A human readable short name of the tool, to be shown on the UI.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 74 class ToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Tool call states. module State # Default value. STATE_UNSPECIFIED = 0 # The tool call has been triggered. TRIGGERED = 1 # The tool call requires confirmation from a human. NEEDS_CONFIRMATION = 2 end end |