Class: Google::Cloud::Dialogflow::V2::ToolCallResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dialogflow::V2::ToolCallResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dialogflow/v2/tool_call.rb
Overview
The result of calling a tool's action.
Defined Under Namespace
Classes: Error
Instance Attribute Summary collapse
-
#action ⇒ ::String
Optional.
-
#answer_record ⇒ ::String
Optional.
-
#ces_app ⇒ ::String
Optional.
-
#ces_tool ⇒ ::String
Optional.
-
#ces_toolset ⇒ ::String
Optional.
-
#content ⇒ ::String
Only populated if the response content is utf-8 encoded.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#error ⇒ ::Google::Cloud::Dialogflow::V2::ToolCallResult::Error
The tool call's error.
-
#raw_content ⇒ ::String
Only populated if the response content is not utf-8 encoded.
-
#tool ⇒ ::String
Optional.
Instance Attribute Details
#action ⇒ ::String
Returns Optional. The name of the tool's action associated with this call.
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 145 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#answer_record ⇒ ::String
Returns Optional. The answer record associated with this tool call result.
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 145 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ces_app ⇒ ::String
Returns Optional. CES app name for this call.
Format:
projects/<ProjectID>/locations/<LocationID>/apps/<AppID>.
Note: The following fields are mutually exclusive: ces_app, tool, ces_toolset, ces_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 145 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ces_tool ⇒ ::String
Returns Optional. CES tool name for this call.
Format:
projects/<ProjectID>/locations/<LocationID>/apps/<AppID>/tools/<ToolID>.
Note: The following fields are mutually exclusive: ces_tool, tool, ces_toolset, ces_app. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 145 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ces_toolset ⇒ ::String
Returns Optional. CES toolset name for this call.
Format:
projects/<ProjectID>/locations/<LocationID>/apps/<AppID>/toolsets/ToolsetID>.
Note: The following fields are mutually exclusive: ces_toolset, tool, ces_tool, ces_app. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 145 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#content ⇒ ::String
Returns Only populated if the response content is utf-8 encoded.
Note: The following fields are mutually exclusive: content, error, raw_content. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 145 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Create time of the tool call result.
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 145 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#error ⇒ ::Google::Cloud::Dialogflow::V2::ToolCallResult::Error
Returns The tool call's error.
Note: The following fields are mutually exclusive: error, raw_content, content. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 145 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#raw_content ⇒ ::String
Returns Only populated if the response content is not utf-8 encoded. (by definition byte fields are base64 encoded).
Note: The following fields are mutually exclusive: raw_content, error, content. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 145 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tool ⇒ ::String
Returns Optional. The tool associated with
this call. Format:
projects/<ProjectID>/locations/<LocationID>/tools/<ToolID>.
Note: The following fields are mutually exclusive: tool, ces_toolset, ces_tool, ces_app. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'proto_docs/google/cloud/dialogflow/v2/tool_call.rb', line 145 class ToolCallResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error produced by the tool call. # @!attribute [rw] message # @return [::String] # Optional. The error message of the function. class Error include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |